@@ -121,10 +121,10 @@ allocation_get_input(int argc, char *argv[])
         }
 }
 /**
- * @brief Sets up allocation classes of service on selected CPU sockets
+ * @brief Sets up allocation classes of service on selected MBA ids
  *
- * @param sock_count number of CPU sockets
- * @param sockets arrays with CPU socket id's
+ * @param mba_count number of CPU mba ids
+ * @param mba_ids arrays
  *
  * @return Number of classes of service set
  * @retval 0 no class of service set (nor selected)
@@ -132,29 +132,29 @@ allocation_get_input(int argc, char *argv[])
  * @retval positive success
  */
 static int
-set_allocation_class(unsigned sock_count,
-                     const unsigned *sockets)
+set_allocation_class(unsigned mba_count,
+                     const unsigned *mba_ids)
 {
-	int ret;
+        int ret;
 
-	while (sock_count > 0 && sel_mba_cos_num > 0) {
-		ret = pqos_mba_set(*sockets,
-                                    sel_mba_cos_num,
-                                    &mba[REQUESTED],
-                                    &mba[ACTUAL]);
-		if  (ret != PQOS_RETVAL_OK) {
+        while (mba_count > 0 && sel_mba_cos_num > 0) {
+                ret = pqos_mba_set(*mba_ids,
+                                   sel_mba_cos_num,
+                                   &mba[REQUESTED],
+                                   &mba[ACTUAL]);
+                if  (ret != PQOS_RETVAL_OK) {
                         printf("Failed to set MBA!\n");
-			return -1;
-		}
+                        return -1;
+                }
                 printf("SKT%u: MBA COS%u => %u%% requested, %u%% applied\n",
-                       *sockets, mba[REQUESTED].class_id,
+                       *mba_ids, mba[REQUESTED].class_id,
                        mba[REQUESTED].mb_max, mba[ACTUAL].mb_max);
 
-		sock_count--;
-		sockets++;
-	}
+                mba_count--;
+                mba_ids++;
+        }
 
-	return sel_mba_cos_num;
+        return sel_mba_cos_num;
 }
 /**
  * @brief Prints allocation configuration
@@ -166,8 +166,8 @@ set_allocation_class(unsigned sock_count,
  */
 static int
 print_allocation_config(const struct pqos_cap *p_cap,
-                        const unsigned sock_count,
-                        const unsigned *sockets)
+                        const unsigned mba_count,
+                        const unsigned *mba_ids)
 {
         const struct pqos_capability *cap = NULL;
         const struct pqos_cap_mba *mba_cap = NULL;
@@ -180,17 +180,17 @@ print_allocation_config(const struct pqos_cap *p_cap,
                 return ret;
         mba_cap = cap->u.mba;
 
-	for (i = 0; i < sock_count; i++) {
+	for (i = 0; i < mba_count; i++) {
                 struct pqos_mba tab[mba_cap->num_classes];
 	        unsigned num = 0;
 
-		ret = pqos_mba_get(sockets[i], mba_cap->num_classes,
+		ret = pqos_mba_get(mba_ids[i], mba_cap->num_classes,
                                    &num, tab);
 		if (ret == PQOS_RETVAL_OK) {
 			unsigned n = 0;
 
                         printf("MBA COS definitions for Socket %u:\n",
-                               sockets[i]);
+                               mba_ids[i]);
 			for (n = 0; n < num; n++) {
 				printf("    MBA COS%u => %u%% available\n",
                                        tab[n].class_id,
@@ -208,7 +208,7 @@ int main(int argc, char *argv[])
 	struct pqos_config cfg;
 	const struct pqos_cpuinfo *p_cpu = NULL;
 	const struct pqos_cap *p_cap = NULL;
-	unsigned sock_count, *p_sockets = NULL;
+	unsigned mba_id_count, *p_mba_ids = NULL;
 	int ret, exit_val = EXIT_SUCCESS;
 
 	memset(&cfg, 0, sizeof(cfg));
@@ -228,10 +228,10 @@ int main(int argc, char *argv[])
 		exit_val = EXIT_FAILURE;
 		goto error_exit;
 	}
-	/* Get CPU socket information to set COS */
-	p_sockets = pqos_cpu_get_sockets(p_cpu, &sock_count);
-	if (p_sockets == NULL) {
-		printf("Error retrieving CPU socket information!\n");
+	/* Get CPU mba_id information to set COS */
+	p_mba_ids = pqos_cpu_get_mba_ids(p_cpu, &mba_id_count);
+	if (p_mba_ids == NULL) {
+		printf("Error retrieving MBA ID information!\n");
 		exit_val = EXIT_FAILURE;
 		goto error_exit;
 	}
@@ -239,7 +239,7 @@ int main(int argc, char *argv[])
 	allocation_get_input(argc, argv);
 	if (sel_mba_cos_num != 0) {
 		/* Set delay value for MBA COS allocation */
-		ret = set_allocation_class(sock_count, p_sockets);
+		ret = set_allocation_class(mba_id_count, p_mba_ids);
 		if (ret < 0) {
 			printf("Allocation configuration error!\n");
 			goto error_exit;
@@ -247,7 +247,7 @@ int main(int argc, char *argv[])
 		printf("Allocation configuration altered.\n");
 	}
 	/* Print COS definition */
-	ret = print_allocation_config(p_cap, sock_count, p_sockets);
+	ret = print_allocation_config(p_cap, mba_id_count, p_mba_ids);
 	if (ret != PQOS_RETVAL_OK) {
 		printf("Allocation capability not detected!\n");
 		exit_val = EXIT_FAILURE;
@@ -258,7 +258,7 @@ int main(int argc, char *argv[])
 	ret = pqos_fini();
 	if (ret != PQOS_RETVAL_OK)
 		printf("Error shutting down PQoS library!\n");
-        if (p_sockets != NULL)
-                free(p_sockets);
+	if (p_mba_ids != NULL)
+		free(p_mba_ids);
 	return exit_val;
 }
