@@ -46,7 +46,7 @@
 #endif
 #include "dlock.h"
 
-#define MAX_SOCK_NUM 16
+#define MAX_L3CAT_NUM 16
 #define DIM(x) (sizeof(x)/sizeof(x[0]))
 
 static int m_is_chunk_allocated = 0;
@@ -56,7 +56,7 @@ static unsigned m_num_clos = 0;
 static struct {
         unsigned id;
         struct pqos_l3ca *cos_tab;
-} m_socket_cos[MAX_SOCK_NUM];
+} m_l3cat_cos[MAX_L3CAT_NUM];
 
 /**
  * @brief Removes the memory block from cache hierarchy
@@ -175,15 +175,15 @@ static int bytes_to_cache_ways(const struct pqos_capability *cat_cap,
 
 int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
 {
-	const struct pqos_cpuinfo *p_cpu = NULL;
-	const struct pqos_cap *p_cap = NULL;
+        const struct pqos_cpuinfo *p_cpu = NULL;
+        const struct pqos_cap *p_cap = NULL;
         const struct pqos_capability *p_l3ca_cap = NULL;
-        unsigned *sockets = NULL;
-        unsigned socket_count = 0, i = 0;
+        unsigned *l3cat_ids = NULL;
+        unsigned l3cat_id_count = 0, i = 0;
         int ret = 0, res = 0;
         size_t num_cache_ways = 0;
         unsigned clos_save = 0;
-	char err_buf[64];
+        char err_buf[64];
 
 #ifdef __linux__
         cpu_set_t cpuset_save, cpuset;
@@ -255,36 +255,36 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
         /**
          * Clear table for restoring CAT configuration
          */
-        for (i = 0; i < DIM(m_socket_cos); i++) {
-                m_socket_cos[i].id = 0;
-                m_socket_cos[i].cos_tab = NULL;
+        for (i = 0; i < DIM(m_l3cat_cos); i++) {
+                m_l3cat_cos[i].id = 0;
+                m_l3cat_cos[i].cos_tab = NULL;
         }
 
         /**
          * Retrieve CPU topology and PQoS capabilities
          */
-	res = pqos_cap_get(&p_cap, &p_cpu);
-	if (res != PQOS_RETVAL_OK) {
-		ret = -5;
-		goto dlock_init_error2;
-	}
+        res = pqos_cap_get(&p_cap, &p_cpu);
+        if (res != PQOS_RETVAL_OK) {
+                ret = -5;
+                goto dlock_init_error2;
+        }
 
         /**
-         * Retrieve list of CPU sockets
+         * Retrieve list of CPU l3cat_ids
          */
-	sockets = pqos_cpu_get_sockets(p_cpu, &socket_count);
-	if (sockets == NULL) {
-		ret = -6;
-		goto dlock_init_error2;
-	}
+        l3cat_ids = pqos_cpu_get_l3cat_ids(p_cpu, &l3cat_id_count);
+        if (l3cat_ids == NULL) {
+                ret = -6;
+                goto dlock_init_error2;
+        }
 
         /**
          * Get CAT capability structure
          */
         res = pqos_cap_get_type(p_cap, PQOS_CAP_TYPE_L3CA, &p_l3ca_cap);
         if (res != PQOS_RETVAL_OK) {
-		ret = -7;
-		goto dlock_init_error2;
+                ret = -7;
+                goto dlock_init_error2;
         }
 
         /**
@@ -292,8 +292,8 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
          */
         res = bytes_to_cache_ways(p_l3ca_cap, size, &num_cache_ways);
         if (res != 0) {
-		ret = -8;
-		goto dlock_init_error2;
+                ret = -8;
+                goto dlock_init_error2;
         }
 
         /**
@@ -302,11 +302,11 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
          */
         m_num_clos = p_l3ca_cap->u.l3ca->num_classes;
 
-        for (i = 0; i < socket_count; i++) {
+        for (i = 0; i < l3cat_id_count; i++) {
                 /**
-                 * This would be enough to run the below code for the socket
+                 * This would be enough to run the below code for the l3cat_id
                  * corresponding to \a cpuid. Yet it is safer to keep CLOS
-                 * definitions coherent across sockets.
+                 * definitions coherent across l3cat_ids.
                  */
                 const uint64_t dlock_mask = (1ULL << num_cache_ways) - 1ULL;
 
@@ -314,8 +314,8 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
                 struct pqos_l3ca cos[m_num_clos];
                 unsigned num = 0, j;
 
-                /* get current CAT classes on this socket */
-                res = pqos_l3ca_get(sockets[i], m_num_clos, &num, &cos[0]);
+                /* get current CAT classes on this l3cat_ids */
+                res = pqos_l3ca_get(l3cat_ids[i], m_num_clos, &num, &cos[0]);
                 if (res != PQOS_RETVAL_OK) {
                         printf("pqos_l3ca_get() error!\n");
                         ret = -9;
@@ -330,15 +330,15 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
                 }
 
                 /* save CAT classes to restore it later */
-                m_socket_cos[i].id = sockets[i];
-                m_socket_cos[i].cos_tab = malloc(m_num_clos * sizeof(cos[0]));
-                if (m_socket_cos[i].cos_tab == NULL) {
+                m_l3cat_cos[i].id = l3cat_ids[i];
+                m_l3cat_cos[i].cos_tab = malloc(m_num_clos * sizeof(cos[0]));
+                if (m_l3cat_cos[i].cos_tab == NULL) {
                         printf("malloc() error!\n");
                         ret = -9;
                         goto dlock_init_error2;
                 }
-                memcpy(m_socket_cos[i].cos_tab, cos,
-                       m_num_clos * sizeof(cos[0]));
+                memcpy(m_l3cat_cos[i].cos_tab, cos,
+                                m_num_clos * sizeof(cos[0]));
 
                 /**
                  * Modify the classes in the following way:
@@ -365,7 +365,7 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
                         }
                 }
 
-                res = pqos_l3ca_set(sockets[i], m_num_clos, &cos[0]);
+                res = pqos_l3ca_set(l3cat_ids[i], m_num_clos, &cos[0]);
                 if (res != PQOS_RETVAL_OK) {
                         printf("pqos_l3ca_set() error!\n");
                         ret = -10;
@@ -418,9 +418,9 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
         }
 
  dlock_init_error2:
-        for (i = 0; (i < DIM(m_socket_cos)) && (ret != 0); i++)
-                if (m_socket_cos[i].cos_tab != NULL)
-                        free(m_socket_cos[i].cos_tab);
+        for (i = 0; (i < DIM(m_l3cat_cos)) && (ret != 0); i++)
+                if (m_l3cat_cos[i].cos_tab != NULL)
+                        free(m_l3cat_cos[i].cos_tab);
 
 #ifdef __linux__
         res = sched_setaffinity(0, sizeof(cpuset_save), &cpuset_save);
@@ -445,8 +445,8 @@ int dlock_init(void *ptr, const size_t size, const int clos, const int cpuid)
                 m_is_chunk_allocated = 0;
         }
 
-        if (sockets != NULL)
-                free(sockets);
+        if (l3cat_ids != NULL)
+                free(l3cat_ids);
 
         return ret;
 }
@@ -459,17 +459,17 @@ int dlock_exit(void)
         if (m_chunk_start == NULL)
                 return -1;
 
-        for (i = 0; i < DIM(m_socket_cos); i++) {
-                if (m_socket_cos[i].cos_tab != NULL) {
-                        int res = pqos_l3ca_set(m_socket_cos[i].id, m_num_clos,
-                                                m_socket_cos[i].cos_tab);
+        for (i = 0; i < DIM(m_l3cat_cos); i++) {
+                if (m_l3cat_cos[i].cos_tab != NULL) {
+                        int res = pqos_l3ca_set(m_l3cat_cos[i].id, m_num_clos,
+                                                m_l3cat_cos[i].cos_tab);
 
                         if (res != PQOS_RETVAL_OK)
                                 ret = -2;
                 }
-                free(m_socket_cos[i].cos_tab);
-                m_socket_cos[i].cos_tab = NULL;
-                m_socket_cos[i].id = 0;
+                free(m_l3cat_cos[i].cos_tab);
+                m_l3cat_cos[i].cos_tab = NULL;
+                m_l3cat_cos[i].id = 0;
         }
 
         if (m_is_chunk_allocated)
