@@ -52,6 +52,7 @@
 #include "machine.h"
 #include "types.h"
 #include "log.h"
+#include "cpu_registers.h"
 
 /**
  * ---------------------------------------
@@ -59,37 +60,6 @@
  * ---------------------------------------
  */
 
-/**
- * Allocation & Monitoring association MSR register
- * - bits [63..32] QE COS
- * - bits [31..10] Reserved
- * - bits [9..0] RMID
- */
-#define PQOS_MSR_ASSOC             0xC8F
-#define PQOS_MSR_ASSOC_QECOS_SHIFT 32
-#define PQOS_MSR_ASSOC_QECOS_MASK  0xffffffff00000000ULL
-
-/**
- * Allocation class of service (COS) MSR registers
- */
-#define PQOS_MSR_L3CA_MASK_START 0xC90
-#define PQOS_MSR_L3CA_MASK_END   0xD0F
-#define PQOS_MSR_L3CA_MASK_NUMOF                                \
-        (PQOS_MSR_L3CA_MASK_END - PQOS_MSR_L3CA_MASK_START + 1)
-
-#define PQOS_MSR_L2CA_MASK_START 0xD10
-#define PQOS_MSR_MBA_MASK_START  0xD50
-
-#define PQOS_MSR_L3_QOS_CFG          0xC81   /**< L3 CAT config register */
-#define PQOS_MSR_L3_QOS_CFG_CDP_EN   1ULL    /**< L3 CDP enable bit */
-
-#define PQOS_MSR_L2_QOS_CFG          0xC82   /**< L2 CAT config register */
-#define PQOS_MSR_L2_QOS_CFG_CDP_EN   1ULL    /**< L2 CDP enable bit */
-
-/**
- * MBA linear max value
- */
-#define PQOS_MBA_LINEAR_MAX 100
 
 /**
  * ---------------------------------------
@@ -135,7 +105,7 @@ get_hi_cos_id(const unsigned technology,
         int ret;
         const struct pqos_cap *cap;
 
-	ASSERT(l2_req || l3_req || mba_req);
+        ASSERT(l2_req || l3_req || mba_req);
         if (hi_class_id == NULL)
                 return PQOS_RETVAL_PARAM;
 
@@ -149,7 +119,7 @@ get_hi_cos_id(const unsigned technology,
                 if (num_l3_cos == 0)
                         return PQOS_RETVAL_ERROR;
 
-		num_cos = num_l3_cos;
+                num_cos = num_l3_cos;
         }
 
         if (l2_req) {
@@ -215,6 +185,10 @@ cos_assoc_get(const unsigned lcore, unsigned *class_id)
  * @param [in] technology selection of allocation technologies
  * @param [out] class_id unused COS
  *
+ * NOTE: It is our assumption that mba id and cat ids are same for
+ * a core. In future, if a core can have different mba id and cat ids
+ * then, we need to change this function to handle it.
+ *
  * @return Operation status
  */
 static int
@@ -223,31 +197,35 @@ get_unused_cos(const unsigned id,
                unsigned *class_id)
 {
         const int l2_req = ((technology & (1 << PQOS_CAP_TYPE_L2CA)) != 0);
+	const int mba_req = ((technology & (1 << PQOS_CAP_TYPE_MBA)) != 0);
         unsigned used_classes[PQOS_MAX_L3CA_COS];
         unsigned i, cos;
-	unsigned hi_class_id;
+        unsigned hi_class_id;
         int ret;
 
         if (class_id == NULL)
                 return PQOS_RETVAL_PARAM;
 
         /* obtain highest class id for all requested technologies */
-	ret = get_hi_cos_id(technology, &hi_class_id);
-	if (ret != PQOS_RETVAL_OK)
+        ret = get_hi_cos_id(technology, &hi_class_id);
+        if (ret != PQOS_RETVAL_OK)
                 return ret;
 
         memset(used_classes, 0, sizeof(used_classes));
 
         /* Create a list of COS used on socket/L2 cluster */
         for (i = 0; i < m_cpu->num_cores; i++) {
-
                 if (l2_req) {
                         /* L2 requested so looking in L2 cluster scope */
                         if (m_cpu->cores[i].l2_id != id)
                                 continue;
+		} else if (mba_req) {
+			/* mba requested so looking in mba_id scope */
+			if (m_cpu->cores[i].mba_id != id)
+				continue;
                 } else {
-                        /* L2 not requested so looking at socket scope */
-                        if (m_cpu->cores[i].socket != id)
+			/* looking at l3cat_id scope */
+			if (m_cpu->cores[i].l3cat_id != id)
                                 continue;
                 }
 
@@ -302,8 +280,8 @@ pqos_alloc_init(const struct pqos_cpuinfo *cpu,
         else
                 m_interface = cfg->interface;
 #ifdef __linux__
-	if (m_interface == PQOS_INTER_OS)
-		ret = os_alloc_init(cpu, cap);
+        if (m_interface == PQOS_INTER_OS)
+                ret = os_alloc_init(cpu, cap);
 #endif
         return ret;
 }
@@ -328,7 +306,7 @@ pqos_alloc_fini(void)
  */
 
 int
-hw_l3ca_set(const unsigned socket,
+hw_l3ca_set(const unsigned l3cat_id,
             const unsigned num_ca,
             const struct pqos_l3ca *ca)
 {
@@ -355,7 +333,7 @@ hw_l3ca_set(const unsigned socket,
                 return ret;
 
         ASSERT(m_cpu != NULL);
-        ret = pqos_cpu_get_one_core(cpu, socket, &core);
+        ret = pqos_cpu_get_one_by_l3cat_id(cpu, l3cat_id, &core);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
@@ -404,7 +382,7 @@ hw_l3ca_set(const unsigned socket,
 }
 
 int
-hw_l3ca_get(const unsigned socket,
+hw_l3ca_get(const unsigned l3cat_id,
             const unsigned max_num_ca,
             unsigned *num_ca,
             struct pqos_l3ca *ca)
@@ -435,7 +413,7 @@ hw_l3ca_get(const unsigned socket,
                 return PQOS_RETVAL_ERROR;
 
         ASSERT(m_cpu != NULL);
-        ret = pqos_cpu_get_one_core(m_cpu, socket, &core);
+        ret = pqos_cpu_get_one_by_l3cat_id(m_cpu, l3cat_id, &core);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
@@ -477,43 +455,43 @@ hw_l3ca_get(const unsigned socket,
 int
 hw_l3ca_get_min_cbm_bits(unsigned *min_cbm_bits)
 {
-	int ret;
-	unsigned *sockets, socket_id, sockets_num;
-	unsigned class_id, l3ca_num, ways, i;
-	int technology = 1 << PQOS_CAP_TYPE_L3CA;
-	const struct pqos_capability *l3_cap = NULL;
-	struct pqos_l3ca l3ca_config[PQOS_MAX_L3CA_COS];
+        int ret;
+        unsigned *l3cat_ids, l3cat_id, l3cat_id_num;
+        unsigned class_id, l3ca_num, ways, i;
+        int technology = 1 << PQOS_CAP_TYPE_L3CA;
+        const struct pqos_capability *l3_cap = NULL;
+        struct pqos_l3ca l3ca_config[PQOS_MAX_L3CA_COS];
 
-	ASSERT(m_cpu != NULL);
-	ASSERT(min_cbm_bits != NULL);
+        ASSERT(m_cpu != NULL);
+        ASSERT(min_cbm_bits != NULL);
 
-	/**
-	 * Get L3 CAT capabilities
-	 */
-	ret = _pqos_cap_get_type(PQOS_CAP_TYPE_L3CA, &l3_cap);
-	if (ret != PQOS_RETVAL_OK)
-		return PQOS_RETVAL_RESOURCE; /* L3 CAT not supported */
+        /**
+         * Get L3 CAT capabilities
+         */
+        ret = _pqos_cap_get_type(PQOS_CAP_TYPE_L3CA, &l3_cap);
+        if (ret != PQOS_RETVAL_OK)
+                return PQOS_RETVAL_RESOURCE; /* L3 CAT not supported */
 
-	/**
-	 * Get number & list of sockets in the system
-	 */
-	sockets = pqos_cpu_get_sockets(m_cpu, &sockets_num);
-	if (sockets == NULL || sockets_num == 0) {
-		ret = PQOS_RETVAL_ERROR;
-		goto pqos_l3ca_get_min_cbm_bits_exit;
-	}
+        /**
+         * Get number & list of l3cat_ids in the system
+         */
+        l3cat_ids = pqos_cpu_get_l3cat_ids(m_cpu, &l3cat_id_num);
+        if (l3cat_ids == NULL || l3cat_id_num == 0) {
+                ret = PQOS_RETVAL_ERROR;
+                goto pqos_l3ca_get_min_cbm_bits_exit;
+        }
 
-	/**
-	 * Find free COS
-	 */
-	for (socket_id = 0; socket_id < sockets_num; socket_id++) {
-		ret = get_unused_cos(socket_id, technology, &class_id);
-		if (ret == PQOS_RETVAL_OK)
-			break;
+        /**
+         * Find free COS
+         */
+        for (l3cat_id = 0; l3cat_id < l3cat_id_num; l3cat_id++) {
+                ret = get_unused_cos(l3cat_id, technology, &class_id);
+                if (ret == PQOS_RETVAL_OK)
+                        break;
 
                 if (ret != PQOS_RETVAL_RESOURCE)
                         goto pqos_l3ca_get_min_cbm_bits_exit;
-	}
+        }
 
         if (ret == PQOS_RETVAL_RESOURCE) {
                 LOG_INFO("No free L3 COS available. "
@@ -521,81 +499,81 @@ hw_l3ca_get_min_cbm_bits(unsigned *min_cbm_bits)
                 goto pqos_l3ca_get_min_cbm_bits_exit;
         }
 
-	/**
-	 * Get current configuration
-	 */
-	ret = hw_l3ca_get(socket_id, PQOS_MAX_L3CA_COS, &l3ca_num, l3ca_config);
-	if (ret != PQOS_RETVAL_OK)
-		goto pqos_l3ca_get_min_cbm_bits_exit;
+        /**
+         * Get current configuration
+         */
+        ret = hw_l3ca_get(l3cat_id, PQOS_MAX_L3CA_COS, &l3ca_num, l3ca_config);
+        if (ret != PQOS_RETVAL_OK)
+                goto pqos_l3ca_get_min_cbm_bits_exit;
 
-	/**
-	 * Probe for min cbm bits
-	 */
-	for (ways = 1; ways <= l3_cap->u.l3ca->num_ways; ways++) {
-		struct pqos_l3ca l3ca_tab[PQOS_MAX_L3CA_COS];
-		unsigned num_ca;
-		uint64_t mask = (1 << ways) - 1;
+        /**
+         * Probe for min cbm bits
+         */
+        for (ways = 1; ways <= l3_cap->u.l3ca->num_ways; ways++) {
+                struct pqos_l3ca l3ca_tab[PQOS_MAX_L3CA_COS];
+                unsigned num_ca;
+                uint64_t mask = (1 << ways) - 1;
 
-		memset(l3ca_tab, 0, sizeof(struct pqos_l3ca));
-		l3ca_tab[0].class_id = class_id;
-		l3ca_tab[0].u.ways_mask = mask;
+                memset(l3ca_tab, 0, sizeof(struct pqos_l3ca));
+                l3ca_tab[0].class_id = class_id;
+                l3ca_tab[0].u.ways_mask = mask;
 
-		/**
-		 * Try to set mask
-		 */
-		ret = hw_l3ca_set(socket_id, 1, l3ca_tab);
-		if (ret != PQOS_RETVAL_OK)
-			continue;
+                /**
+                 * Try to set mask
+                 */
+                ret = hw_l3ca_set(l3cat_id, 1, l3ca_tab);
+                if (ret != PQOS_RETVAL_OK)
+                        continue;
 
-		/**
-		 * Validate if mask was correctly set
-		 */
-		ret = hw_l3ca_get(socket_id, PQOS_MAX_L3CA_COS, &num_ca,
-		                  l3ca_tab);
-		if (ret != PQOS_RETVAL_OK)
-			goto pqos_l3ca_get_min_cbm_bits_restore;
+                /**
+                 * Validate if mask was correctly set
+                 */
+                ret = hw_l3ca_get(l3cat_id, PQOS_MAX_L3CA_COS, &num_ca,
+                                  l3ca_tab);
+                if (ret != PQOS_RETVAL_OK)
+                        goto pqos_l3ca_get_min_cbm_bits_restore;
 
-		for (i = 0; i < num_ca; i++) {
-			struct pqos_l3ca *l3ca = &(l3ca_tab[i]);
+                for (i = 0; i < num_ca; i++) {
+                        struct pqos_l3ca *l3ca = &(l3ca_tab[i]);
 
-			if (l3ca->class_id != class_id)
-				continue;
+                        if (l3ca->class_id != class_id)
+                                continue;
 
-			if ((l3ca->cdp &&
-				l3ca->u.s.data_mask == mask &&
-				l3ca->u.s.code_mask == mask) ||
-			    (!l3ca->cdp && l3ca->u.ways_mask == mask)) {
-				*min_cbm_bits = ways;
-				ret = PQOS_RETVAL_OK;
-				goto pqos_l3ca_get_min_cbm_bits_restore;
-			}
-		}
-	}
+                        if ((l3ca->cdp &&
+                                l3ca->u.s.data_mask == mask &&
+                                l3ca->u.s.code_mask == mask) ||
+                            (!l3ca->cdp && l3ca->u.ways_mask == mask)) {
+                                *min_cbm_bits = ways;
+                                ret = PQOS_RETVAL_OK;
+                                goto pqos_l3ca_get_min_cbm_bits_restore;
+                        }
+                }
+        }
 
-	/**
-	 * Restore old settings
-	 */
+        /**
+         * Restore old settings
+         */
  pqos_l3ca_get_min_cbm_bits_restore:
-	for (i = 0; i < l3ca_num; i++) {
-		int ret_val;
+        for (i = 0; i < l3ca_num; i++) {
+                int ret_val;
 
-		if (l3ca_config[i].class_id != class_id)
-			continue;
+                if (l3ca_config[i].class_id != class_id)
+                        continue;
 
-		ret_val = hw_l3ca_set(socket_id, 1, &(l3ca_config[i]));
-		if (ret_val != PQOS_RETVAL_OK) {
-			LOG_ERROR("Failed to restore CAT configuration. CAT"
-			          " configuration has been altered!\n");
-			ret = ret_val;
-			break;
-		}
-	}
+                ret_val = hw_l3ca_set(l3cat_id, 1, &(l3ca_config[i]));
+                if (ret_val != PQOS_RETVAL_OK) {
+                        LOG_ERROR("Failed to restore CAT configuration. CAT"
+                                  " configuration has been altered!\n");
+                        ret = ret_val;
+                        break;
+                }
+        }
 
  pqos_l3ca_get_min_cbm_bits_exit:
-	if (sockets != NULL)
-		free(sockets);
+        if (l3cat_ids != NULL)
+                free(l3cat_ids);
 
-	return ret;
+        return ret;
 }
 
 int
@@ -699,23 +677,23 @@ hw_l2ca_get(const unsigned l2id,
         int cdp_enabled = 0;
         const struct pqos_cap *cap;
 
-	ASSERT(num_ca != NULL);
-	ASSERT(ca != NULL);
-	ASSERT(max_num_ca != 0);
+        ASSERT(num_ca != NULL);
+        ASSERT(ca != NULL);
+        ASSERT(max_num_ca != 0);
 
         _pqos_cap_get(&cap, NULL);
 
-	ret = pqos_l2ca_get_cos_num(cap, &count);
-	if (ret != PQOS_RETVAL_OK)
-		return PQOS_RETVAL_RESOURCE; /* L2 CAT not supported */
+        ret = pqos_l2ca_get_cos_num(cap, &count);
+        if (ret != PQOS_RETVAL_OK)
+                return PQOS_RETVAL_RESOURCE; /* L2 CAT not supported */
 
         ret = pqos_l2ca_cdp_enabled(cap, NULL, &cdp_enabled);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
-	if (max_num_ca < count)
-		/* Not enough space to store the classes */
-		return PQOS_RETVAL_PARAM;
+        if (max_num_ca < count)
+                /* Not enough space to store the classes */
+                return PQOS_RETVAL_PARAM;
 
         ASSERT(m_cpu != NULL);
         ret = pqos_cpu_get_one_by_l2id(m_cpu, l2id, &core);
@@ -756,48 +734,48 @@ hw_l2ca_get(const unsigned l2id,
         }
         *num_ca = count;
 
-	return ret;
+        return ret;
 }
 
 int
 hw_l2ca_get_min_cbm_bits(unsigned *min_cbm_bits)
 {
-	int ret;
+        int ret;
         unsigned *l2ids = NULL, l2id_num = 0, l2id;
-	unsigned class_id, l2ca_num, ways, i;
-	int technology = 1 << PQOS_CAP_TYPE_L2CA;
-	const struct pqos_capability *l2_cap = NULL;
-	struct pqos_l2ca l2ca_config[PQOS_MAX_L2CA_COS];
+        unsigned class_id, l2ca_num, ways, i;
+        int technology = 1 << PQOS_CAP_TYPE_L2CA;
+        const struct pqos_capability *l2_cap = NULL;
+        struct pqos_l2ca l2ca_config[PQOS_MAX_L2CA_COS];
 
-	ASSERT(m_cpu != NULL);
-	ASSERT(min_cbm_bits != NULL);
+        ASSERT(m_cpu != NULL);
+        ASSERT(min_cbm_bits != NULL);
 
-	/**
-	 * Get L2 CAT capabilities
-	 */
-	ret = _pqos_cap_get_type(PQOS_CAP_TYPE_L2CA, &l2_cap);
-	if (ret != PQOS_RETVAL_OK)
-		return PQOS_RETVAL_RESOURCE; /* L2 CAT not supported */
+        /**
+         * Get L2 CAT capabilities
+         */
+        ret = _pqos_cap_get_type(PQOS_CAP_TYPE_L2CA, &l2_cap);
+        if (ret != PQOS_RETVAL_OK)
+                return PQOS_RETVAL_RESOURCE; /* L2 CAT not supported */
 
         /**
         * Get number & list of L2ids in the system
         */
         l2ids = pqos_cpu_get_l2ids(m_cpu, &l2id_num);
         if (l2ids == NULL || l2id_num == 0) {
-		ret = PQOS_RETVAL_ERROR;
-		goto hw_l2ca_get_min_cbm_bits_exit;
-	}
+                ret = PQOS_RETVAL_ERROR;
+                goto hw_l2ca_get_min_cbm_bits_exit;
+        }
 
-	/**
-	 * Find free COS
-	 */
-	for (l2id = 0; l2id < l2id_num; l2id++) {
-		ret = get_unused_cos(l2id, technology, &class_id);
-		if (ret == PQOS_RETVAL_OK)
-			break;
+        /**
+         * Find free COS
+         */
+        for (l2id = 0; l2id < l2id_num; l2id++) {
+                ret = get_unused_cos(l2id, technology, &class_id);
+                if (ret == PQOS_RETVAL_OK)
+                        break;
                 if (ret != PQOS_RETVAL_RESOURCE)
                         goto hw_l2ca_get_min_cbm_bits_exit;
-	}
+        }
 
         if (ret == PQOS_RETVAL_RESOURCE) {
                 LOG_INFO("No free L2 COS available. "
@@ -805,44 +783,44 @@ hw_l2ca_get_min_cbm_bits(unsigned *min_cbm_bits)
                 goto hw_l2ca_get_min_cbm_bits_exit;
         }
 
-	/**
-	 * Get current configuration
-	 */
-	ret = hw_l2ca_get(l2id, PQOS_MAX_L2CA_COS, &l2ca_num, l2ca_config);
-	if (ret != PQOS_RETVAL_OK)
-		goto hw_l2ca_get_min_cbm_bits_exit;
+        /**
+         * Get current configuration
+         */
+        ret = hw_l2ca_get(l2id, PQOS_MAX_L2CA_COS, &l2ca_num, l2ca_config);
+        if (ret != PQOS_RETVAL_OK)
+                goto hw_l2ca_get_min_cbm_bits_exit;
 
-	/**
-	 * Probe for min cbm bits
-	 */
-	for (ways = 1; ways <= l2_cap->u.l2ca->num_ways; ways++) {
-		struct pqos_l2ca l2ca_tab[PQOS_MAX_L2CA_COS];
-		unsigned num_ca;
-		uint64_t mask = (1 << ways) - 1;
+        /**
+         * Probe for min cbm bits
+         */
+        for (ways = 1; ways <= l2_cap->u.l2ca->num_ways; ways++) {
+                struct pqos_l2ca l2ca_tab[PQOS_MAX_L2CA_COS];
+                unsigned num_ca;
+                uint64_t mask = (1 << ways) - 1;
 
-		memset(l2ca_tab, 0, sizeof(struct pqos_l2ca));
-		l2ca_tab[0].class_id = class_id;
-		l2ca_tab[0].u.ways_mask = mask;
+                memset(l2ca_tab, 0, sizeof(struct pqos_l2ca));
+                l2ca_tab[0].class_id = class_id;
+                l2ca_tab[0].u.ways_mask = mask;
 
-		/**
-		 * Try to set mask
-		 */
-		ret = hw_l2ca_set(l2id, 1, l2ca_tab);
-		if (ret != PQOS_RETVAL_OK)
-			continue;
+                /**
+                 * Try to set mask
+                 */
+                ret = hw_l2ca_set(l2id, 1, l2ca_tab);
+                if (ret != PQOS_RETVAL_OK)
+                        continue;
 
-		/**
-		 * Validate if mask was correctly set
-		 */
-		ret = hw_l2ca_get(l2id, PQOS_MAX_L2CA_COS, &num_ca, l2ca_tab);
-		if (ret != PQOS_RETVAL_OK)
-			goto hw_l2ca_get_min_cbm_bits_restore;
+                /**
+                 * Validate if mask was correctly set
+                 */
+                ret = hw_l2ca_get(l2id, PQOS_MAX_L2CA_COS, &num_ca, l2ca_tab);
+                if (ret != PQOS_RETVAL_OK)
+                        goto hw_l2ca_get_min_cbm_bits_restore;
 
-		for (i = 0; i < num_ca; i++) {
-			struct pqos_l2ca *l2ca = &(l2ca_tab[i]);
+                for (i = 0; i < num_ca; i++) {
+                        struct pqos_l2ca *l2ca = &(l2ca_tab[i]);
 
-			if (l2ca->class_id != class_id)
-				continue;
+                        if (l2ca->class_id != class_id)
+                                continue;
 
                         if ((l2ca->cdp &&
                                 l2ca->u.s.data_mask == mask &&
@@ -852,37 +830,37 @@ hw_l2ca_get_min_cbm_bits(unsigned *min_cbm_bits)
                                 ret = PQOS_RETVAL_OK;
                                 goto hw_l2ca_get_min_cbm_bits_restore;
                         }
-		}
-	}
+                }
+        }
 
-	/**
-	 * Restore old settings
-	 */
+        /**
+         * Restore old settings
+         */
  hw_l2ca_get_min_cbm_bits_restore:
-	for (i = 0; i < l2ca_num; i++) {
-		int ret_val;
+        for (i = 0; i < l2ca_num; i++) {
+                int ret_val;
 
-		if (l2ca_config[i].class_id != class_id)
-			continue;
+                if (l2ca_config[i].class_id != class_id)
+                        continue;
 
-		ret_val = hw_l2ca_set(l2id, 1, &(l2ca_config[i]));
-		if (ret_val != PQOS_RETVAL_OK) {
-			LOG_ERROR("Failed to restore CAT configuration. CAT"
-			          " configuration has been altered!\n");
-			ret = ret_val;
-			break;
-		}
-	}
+                ret_val = hw_l2ca_set(l2id, 1, &(l2ca_config[i]));
+                if (ret_val != PQOS_RETVAL_OK) {
+                        LOG_ERROR("Failed to restore CAT configuration. CAT"
+                                  " configuration has been altered!\n");
+                        ret = ret_val;
+                        break;
+                }
+        }
 
  hw_l2ca_get_min_cbm_bits_exit:
         if (l2ids != NULL)
                 free(l2ids);
 
-	return ret;
+        return ret;
 }
 
 int
-hw_mba_set(const unsigned socket,
+hw_mba_set(const unsigned mba_id,
            const unsigned num_cos,
            const struct pqos_mba *requested,
            struct pqos_mba *actual)
@@ -892,7 +870,7 @@ hw_mba_set(const unsigned socket,
         const struct pqos_capability *mba_cap = NULL;
 
         ASSERT(requested != NULL);
-	ASSERT(num_cos != 0);
+        ASSERT(num_cos != 0);
 
         /**
          * Check if MBA is supported
@@ -913,7 +891,7 @@ hw_mba_set(const unsigned socket,
         }
         /**
          * Check if class id's are within allowed range
-	 * and if a controller is not requested.
+         * and if a controller is not requested.
          */
         for (i = 0; i < num_cos; i++) {
                 if (requested[i].class_id >= count) {
@@ -929,7 +907,7 @@ hw_mba_set(const unsigned socket,
         }
 
         ASSERT(m_cpu != NULL);
-        ret = pqos_cpu_get_one_core(m_cpu, socket, &core);
+        ret = pqos_cpu_get_one_by_mba_id(m_cpu, mba_id, &core);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
@@ -966,7 +944,7 @@ hw_mba_set(const unsigned socket,
 }
 
 int
-hw_mba_get(const unsigned socket,
+hw_mba_get(const unsigned mba_id,
            const unsigned max_num_cos,
            unsigned *num_cos,
            struct pqos_mba *mba_tab)
@@ -976,8 +954,8 @@ hw_mba_get(const unsigned socket,
         const struct pqos_cap *cap;
 
         ASSERT(num_cos != NULL);
-	ASSERT(mba_tab != NULL);
-	ASSERT(max_num_cos != 0);
+        ASSERT(mba_tab != NULL);
+        ASSERT(max_num_cos != 0);
 
         _pqos_cap_get(&cap, NULL);
 
@@ -989,7 +967,7 @@ hw_mba_get(const unsigned socket,
                 return PQOS_RETVAL_ERROR;
 
         ASSERT(m_cpu != NULL);
-        ret = pqos_cpu_get_one_core(m_cpu, socket, &core);
+        ret = pqos_cpu_get_one_by_mba_id(m_cpu, mba_id, &core);
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
@@ -1104,7 +1082,7 @@ hw_alloc_assoc_get(const unsigned lcore,
 
         ret = cos_assoc_get(lcore, class_id);
 
-	return ret;
+        return ret;
 }
 
 
@@ -1115,14 +1093,15 @@ hw_alloc_assign(const unsigned technology,
                 unsigned *class_id)
 {
         const int l2_req = ((technology & (1 << PQOS_CAP_TYPE_L2CA)) != 0);
+	const int mba_req = ((technology & (1 << PQOS_CAP_TYPE_MBA)) != 0);
+	unsigned resource_id = 0;
         unsigned i;
-        unsigned socket = 0, l2id = 0;
         int ret;
 
         ASSERT(core_num > 0);
-	ASSERT(core_array != NULL);
-	ASSERT(class_id != NULL);
-	ASSERT(technology != 0);
+        ASSERT(core_array != NULL);
+        ASSERT(class_id != NULL);
+        ASSERT(technology != 0);
 
         /* Check if core belongs to one resource entity */
         for (i = 0; i < core_num; i++) {
@@ -1138,25 +1117,28 @@ hw_alloc_assign(const unsigned technology,
                         /* L2 is requested
                          * The smallest manageable entity is L2 cluster
                          */
-                        if (i != 0 && l2id != pi->l2_id) {
+                        if (i != 0 && resource_id != pi->l2_id) {
                                 ret = PQOS_RETVAL_PARAM;
                                 goto pqos_alloc_assign_exit;
                         }
-                        l2id = pi->l2_id;
-                } else {
-                        if (i != 0 && socket != pi->socket) {
+                        resource_id = pi->l2_id;
+		} else if (mba_req) {
+			if (i != 0 && resource_id != pi->mba_id) {
+				ret = PQOS_RETVAL_PARAM;
+				goto pqos_alloc_assign_exit;
+			}
+			resource_id = pi->mba_id;
+		} else {
+			if (i != 0 && resource_id != pi->l3cat_id) {
                                 ret = PQOS_RETVAL_PARAM;
                                 goto pqos_alloc_assign_exit;
                         }
-                        socket = pi->socket;
+			resource_id = pi->l3cat_id;
                 }
         }
 
         /* find an unused class from highest down */
-        if (!l2_req)
-                ret = get_unused_cos(socket, technology, class_id);
-        else
-                ret = get_unused_cos(l2id, technology, class_id);
+	ret = get_unused_cos(resource_id, technology, class_id);
 
         if (ret != PQOS_RETVAL_OK)
                 goto pqos_alloc_assign_exit;
@@ -1200,23 +1182,23 @@ hw_alloc_release(const unsigned *core_array,
  * @retval PQOS_RETVAL_ERROR on failure, MSR read/write error
  */
 static int
-l3cdp_enable(const unsigned sockets_num,
-           const unsigned *sockets,
-           const int enable)
+l3cdp_enable(const unsigned l3cat_id_num,
+             const unsigned *l3cat_ids,
+             const int enable)
 {
         unsigned j = 0;
 
-        ASSERT(sockets_num > 0 && sockets != NULL);
+        ASSERT(l3cat_id_num > 0 && l3cat_ids != NULL);
 
         LOG_INFO("%s L3 CDP across sockets...\n",
                  (enable) ? "Enabling" : "Disabling");
 
-        for (j = 0; j < sockets_num; j++) {
+        for (j = 0; j < l3cat_id_num; j++) {
                 uint64_t reg = 0;
                 unsigned core = 0;
                 int ret = PQOS_RETVAL_OK;
 
-                ret = pqos_cpu_get_one_core(m_cpu, sockets[j], &core);
+                ret = pqos_cpu_get_one_by_l3cat_id(m_cpu, l3cat_ids[j], &core);
                 if (ret != PQOS_RETVAL_OK)
                         return ret;
 
@@ -1346,8 +1328,10 @@ hw_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
                const enum pqos_cdp_config l2_cdp_cfg,
                const enum pqos_mba_config mba_cfg)
 {
-        unsigned *sockets = NULL;
-        unsigned sockets_num = 0;
+        unsigned *l3cat_ids = NULL;
+        unsigned l3cat_id_num = 0;
+        unsigned *mba_ids = NULL;
+        unsigned mba_id_num = 0;
         unsigned *l2ids = NULL;
         unsigned l2id_num = 0;
         const struct pqos_cap *cap;
@@ -1460,22 +1444,23 @@ hw_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
                 goto pqos_alloc_reset_exit;
         }
 
-        /**
-         * Get number & list of sockets in the system
-         */
-        sockets = pqos_cpu_get_sockets(m_cpu, &sockets_num);
-        if (sockets == NULL || sockets_num == 0)
-                goto pqos_alloc_reset_exit;
-
         if (l3_cap != NULL) {
                 /**
-                 * Change L3 COS definition on all sockets
+                 * Get number & list of l3cat_ids in the system
+                 */
+                l3cat_ids = pqos_cpu_get_l3cat_ids(m_cpu, &l3cat_id_num);
+                if (l3cat_ids == NULL || l3cat_id_num == 0)
+                        goto pqos_alloc_reset_exit;
+                /**
+                 * Change L3 COS definition on all l3cat ids
                  * so that each COS allows for access to all cache ways
                  */
-                for (j = 0; j < sockets_num; j++) {
+                for (j = 0; j < l3cat_id_num; j++) {
                         unsigned core = 0;
 
-                        ret = pqos_cpu_get_one_core(m_cpu, sockets[j], &core);
+                        ret = pqos_cpu_get_one_by_l3cat_id(m_cpu,
+                                                           l3cat_ids[j],
+                                                           &core);
                         if (ret != PQOS_RETVAL_OK)
                                 goto pqos_alloc_reset_exit;
 
@@ -1516,13 +1501,21 @@ hw_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
 
         if (mba_cap != NULL) {
                 /**
-                 * Go through all sockets and reset MBA class defintions
+                 * Get number & list of mba_ids in the system
+                 */
+                mba_ids = pqos_cpu_get_mba_ids(m_cpu, &mba_id_num);
+                if (mba_ids == NULL || mba_id_num == 0)
+                        goto pqos_alloc_reset_exit;
+
+                /**
+                 * Go through all L3 CAT ids and reset MBA class definitions
                  * 0 is the default MBA COS value in linear mode.
                  */
-                for (j = 0; j < sockets_num; j++) {
+                for (j = 0; j < mba_id_num; j++) {
                         unsigned core = 0;
 
-                        ret = pqos_cpu_get_one_core(m_cpu, sockets[j], &core);
+                        ret = pqos_cpu_get_one_by_mba_id(m_cpu, mba_ids[j],
+                                                         &core);
                         if (ret != PQOS_RETVAL_OK)
                                 goto pqos_alloc_reset_exit;
 
@@ -1549,7 +1542,7 @@ hw_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
                          * Turn on L3 CDP
                          */
                         LOG_INFO("Turning L3 CDP ON ...\n");
-                        ret = l3cdp_enable(sockets_num, sockets, 1);
+                        ret = l3cdp_enable(l3cat_id_num, l3cat_ids, 1);
                         if (ret != PQOS_RETVAL_OK) {
                                 LOG_ERROR("L3 CDP enable error!\n");
                                 goto pqos_alloc_reset_exit;
@@ -1561,7 +1554,7 @@ hw_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
                          * Turn off L3 CDP
                          */
                         LOG_INFO("Turning L3 CDP OFF ...\n");
-                        ret = l3cdp_enable(sockets_num, sockets, 0);
+                        ret = l3cdp_enable(l3cat_id_num, l3cat_ids, 0);
                         if (ret != PQOS_RETVAL_OK) {
                                 LOG_ERROR("L3 CDP disable error!\n");
                                 goto pqos_alloc_reset_exit;
@@ -1601,8 +1594,10 @@ hw_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
         }
 
  pqos_alloc_reset_exit:
-        if (sockets != NULL)
-                free(sockets);
+        if (l3cat_ids != NULL)
+                free(l3cat_ids);
+        if (mba_ids != NULL)
+                free(mba_ids);
         if (l2ids != NULL)
                 free(l2ids);
         return ret;
