@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,6 +44,7 @@
 #include "cap.h"
 #include "log.h"
 #include "types.h"
+#include "cpu_registers.h"
 
 /**
  * Value marking monitoring group structure as "valid".
@@ -67,7 +68,8 @@ static int m_interface = PQOS_INTER_MSR;
 int
 api_init(int interface)
 {
-        if (interface != PQOS_INTER_MSR && interface != PQOS_INTER_OS)
+        if (interface != PQOS_INTER_MSR && interface != PQOS_INTER_OS &&
+                interface != PQOS_INTER_OS_RESCTRL_MON)
                 return PQOS_RETVAL_PARAM;
 
         m_interface = interface;
@@ -84,9 +86,9 @@ int
 pqos_alloc_assoc_set(const unsigned lcore,
                      const unsigned class_id)
 {
-	int ret;
+        int ret;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -94,31 +96,31 @@ pqos_alloc_assoc_set(const unsigned lcore,
                 return ret;
         }
 
-	if (m_interface == PQOS_INTER_MSR)
-		ret = hw_alloc_assoc_set(lcore, class_id);
-	else {
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_alloc_assoc_set(lcore, class_id);
+        else {
 #ifdef __linux__
-		ret = os_alloc_assoc_set(lcore, class_id);
+                ret = os_alloc_assoc_set(lcore, class_id);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
 pqos_alloc_assoc_get(const unsigned lcore,
                      unsigned *class_id)
 {
-	int ret;
+        int ret;
 
-	if (class_id == NULL)
-		return PQOS_RETVAL_PARAM;
+        if (class_id == NULL)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -126,19 +128,19 @@ pqos_alloc_assoc_get(const unsigned lcore,
                 return ret;
         }
 
-	if (m_interface == PQOS_INTER_MSR)
-		ret = hw_alloc_assoc_get(lcore, class_id);
-	else {
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_alloc_assoc_get(lcore, class_id);
+        else {
 #ifdef __linux__
-		ret = os_alloc_assoc_get(lcore, class_id);
+                ret = os_alloc_assoc_get(lcore, class_id);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
@@ -147,7 +149,7 @@ pqos_alloc_assoc_set_pid(const pid_t task,
 {
         int ret;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -155,7 +157,8 @@ pqos_alloc_assoc_set_pid(const pid_t task,
                 return ret;
         }
 
-        if (m_interface != PQOS_INTER_OS) {
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -170,9 +173,9 @@ pqos_alloc_assoc_set_pid(const pid_t task,
         LOG_INFO("OS interface not supported!\n");
         ret = PQOS_RETVAL_RESOURCE;
 #endif
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 
 }
 
@@ -180,12 +183,12 @@ int
 pqos_alloc_assoc_get_pid(const pid_t task,
                          unsigned *class_id)
 {
-	int ret;
+        int ret;
 
-	if (class_id == NULL)
-		return PQOS_RETVAL_PARAM;
+        if (class_id == NULL)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -193,7 +196,8 @@ pqos_alloc_assoc_get_pid(const pid_t task,
                 return ret;
         }
 
-        if (m_interface != PQOS_INTER_OS) {
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -208,9 +212,9 @@ pqos_alloc_assoc_get_pid(const pid_t task,
         LOG_INFO("OS interface not supported!\n");
         ret = PQOS_RETVAL_RESOURCE;
 #endif
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
@@ -219,16 +223,16 @@ pqos_alloc_assign(const unsigned technology,
                   const unsigned core_num,
                   unsigned *class_id)
 {
-	int ret;
-	const int l2_req = ((technology & (1 << PQOS_CAP_TYPE_L2CA)) != 0);
-	const int l3_req = ((technology & (1 << PQOS_CAP_TYPE_L3CA)) != 0);
-	const int mba_req = ((technology & (1 << PQOS_CAP_TYPE_MBA)) != 0);
+        int ret;
+        const int l2_req = ((technology & (1 << PQOS_CAP_TYPE_L2CA)) != 0);
+        const int l3_req = ((technology & (1 << PQOS_CAP_TYPE_L3CA)) != 0);
+        const int mba_req = ((technology & (1 << PQOS_CAP_TYPE_MBA)) != 0);
 
         if (core_num == 0 || core_array == NULL || class_id == NULL ||
             !(l2_req || l3_req || mba_req))
                 return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -241,13 +245,13 @@ pqos_alloc_assign(const unsigned technology,
         else {
 #ifdef __linux__
                 ret = os_alloc_assign(technology, core_array, core_num,
-		                      class_id);
+                                      class_id);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
         return ret;
 }
@@ -256,12 +260,12 @@ int
 pqos_alloc_release(const unsigned *core_array,
                    const unsigned core_num)
 {
-	int ret;
+        int ret;
 
         if (core_num == 0 || core_array == NULL)
                 return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -279,9 +283,9 @@ pqos_alloc_release(const unsigned *core_array,
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
@@ -295,7 +299,7 @@ pqos_alloc_assign_pid(const unsigned technology,
         if (task_array == NULL || task_num == 0 || class_id == NULL)
                 return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -303,7 +307,8 @@ pqos_alloc_assign_pid(const unsigned technology,
                 return ret;
         }
 
-        if (m_interface != PQOS_INTER_OS) {
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -317,9 +322,9 @@ pqos_alloc_assign_pid(const unsigned technology,
         LOG_INFO("OS interface not supported!\n");
         ret = PQOS_RETVAL_RESOURCE;
 #endif
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
@@ -331,7 +336,7 @@ pqos_alloc_release_pid(const pid_t *task_array,
         if (task_array == NULL || task_num == 0)
                 return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -339,7 +344,8 @@ pqos_alloc_release_pid(const pid_t *task_array,
                 return ret;
         }
 
-        if (m_interface != PQOS_INTER_OS) {
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 _pqos_api_unlock();
@@ -352,15 +358,17 @@ pqos_alloc_release_pid(const pid_t *task_array,
         LOG_INFO("OS interface not supported!\n");
         ret = PQOS_RETVAL_RESOURCE;
 #endif
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
-pqos_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg)
+pqos_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
+                 const enum pqos_cdp_config l2_cdp_cfg,
+                 const enum pqos_mba_config mba_cfg)
 {
-	int ret;
+        int ret;
 
         if (l3_cdp_cfg != PQOS_REQUIRE_CDP_ON &&
             l3_cdp_cfg != PQOS_REQUIRE_CDP_OFF &&
@@ -370,6 +378,22 @@ pqos_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg)
                 return PQOS_RETVAL_PARAM;
         }
 
+        if (l2_cdp_cfg != PQOS_REQUIRE_CDP_ON &&
+            l2_cdp_cfg != PQOS_REQUIRE_CDP_OFF &&
+            l2_cdp_cfg != PQOS_REQUIRE_CDP_ANY) {
+                LOG_ERROR("Unrecognized L2 CDP configuration setting %d!\n",
+                          l2_cdp_cfg);
+                return PQOS_RETVAL_PARAM;
+        }
+
+        if (mba_cfg != PQOS_MBA_ANY &&
+            mba_cfg != PQOS_MBA_DEFAULT &&
+            mba_cfg != PQOS_MBA_CTRL) {
+                LOG_ERROR("Unrecognized MBA configuration setting %d!\n",
+                          mba_cfg);
+                return PQOS_RETVAL_PARAM;
+        }
+
         _pqos_api_lock();
 
         ret = _pqos_check_init(1);
@@ -378,19 +402,19 @@ pqos_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg)
                 return ret;
         }
 
-	if (m_interface == PQOS_INTER_MSR)
-                ret = hw_alloc_reset(l3_cdp_cfg);
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_alloc_reset(l3_cdp_cfg, l2_cdp_cfg, mba_cfg);
         else {
 #ifdef __linux__
-                ret = os_alloc_reset(l3_cdp_cfg);
+                ret = os_alloc_reset(l3_cdp_cfg, l2_cdp_cfg, mba_cfg);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 unsigned *
@@ -402,7 +426,8 @@ pqos_pid_get_pid_assoc(const unsigned class_id, unsigned *count)
         if (count == NULL)
                 return NULL;
 
-        if (m_interface != PQOS_INTER_OS) {
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task association!\n");
                 return NULL;
@@ -465,17 +490,17 @@ is_contiguous(uint64_t bitmask)
 }
 
 int
-pqos_l3ca_set(const unsigned socket,
+pqos_l3ca_set(const unsigned l3cat_id,
               const unsigned num_cos,
               const struct pqos_l3ca *ca)
 {
-	int ret;
-	unsigned i;
+        int ret;
+        unsigned i;
 
-	if (ca == NULL || num_cos == 0)
-		return PQOS_RETVAL_PARAM;
+        if (ca == NULL || num_cos == 0)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -483,72 +508,104 @@ pqos_l3ca_set(const unsigned socket,
                 return ret;
         }
 
-	/**
-	 * Check if class bitmasks are contiguous.
-	 */
-	for (i = 0; i < num_cos; i++) {
-		int is_contig = 0;
+        /**
+         * Check if class bitmasks are contiguous.
+         */
+        for (i = 0; i < num_cos; i++) {
+                int is_contig = 0;
 
-		if (ca[i].cdp) {
-			is_contig = is_contiguous(ca[i].u.s.data_mask) &&
-				is_contiguous(ca[i].u.s.code_mask);
-		} else
-			is_contig = is_contiguous(ca[i].u.ways_mask);
+                if (ca[i].cdp) {
+                        is_contig = is_contiguous(ca[i].u.s.data_mask) &&
+                                is_contiguous(ca[i].u.s.code_mask);
+                } else
+                        is_contig = is_contiguous(ca[i].u.ways_mask);
 
-		if (!is_contig) {
-			LOG_ERROR("L3 COS%u bit mask is not contiguous!\n",
-			          ca[i].class_id);
-			_pqos_api_unlock();
-			return PQOS_RETVAL_PARAM;
-		}
-	}
+                if (!is_contig) {
+                        LOG_ERROR("L3 COS%u bit mask is not contiguous!\n",
+                                  ca[i].class_id);
+                        _pqos_api_unlock();
+                        return PQOS_RETVAL_PARAM;
+                }
+        }
 
-	if (m_interface == PQOS_INTER_MSR)
-		ret = hw_l3ca_set(socket, num_cos, ca);
-	else {
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_l3ca_set(l3cat_id, num_cos, ca);
+        else {
 #ifdef __linux__
-		ret = os_l3ca_set(socket, num_cos, ca);
+                ret = os_l3ca_set(l3cat_id, num_cos, ca);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
-pqos_l3ca_get(const unsigned socket,
+pqos_l3ca_get(const unsigned l3cat_id,
               const unsigned max_num_ca,
               unsigned *num_ca,
               struct pqos_l3ca *ca)
 {
-	int ret;
+        int ret;
 
-	if (num_ca == NULL || ca == NULL || max_num_ca == 0)
-		return PQOS_RETVAL_PARAM;
+        if (num_ca == NULL || ca == NULL || max_num_ca == 0)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
                 _pqos_api_unlock();
                 return ret;
         }
-	if (m_interface == PQOS_INTER_MSR)
-		ret = hw_l3ca_get(socket, max_num_ca, num_ca, ca);
-	else {
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_l3ca_get(l3cat_id, max_num_ca, num_ca, ca);
+        else {
 #ifdef __linux__
-		ret = os_l3ca_get(socket, max_num_ca, num_ca, ca);
+                ret = os_l3ca_get(l3cat_id, max_num_ca, num_ca, ca);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
+}
+
+int
+pqos_l3ca_get_min_cbm_bits(unsigned *min_cbm_bits)
+{
+        int ret;
+
+        if (min_cbm_bits == NULL)
+                return PQOS_RETVAL_PARAM;
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_l3ca_get_min_cbm_bits(min_cbm_bits);
+        else {
+#ifdef __linux__
+                ret = os_l3ca_get_min_cbm_bits(min_cbm_bits);
+#else
+                LOG_INFO("OS interface not supported!\n");
+                ret = PQOS_RETVAL_RESOURCE;
+#endif
+        }
+
+        _pqos_api_unlock();
+
+        return ret;
 }
 
 /*
@@ -562,13 +619,13 @@ pqos_l2ca_set(const unsigned l2id,
               const unsigned num_cos,
               const struct pqos_l2ca *ca)
 {
-	int ret;
-	unsigned i;
+        int ret;
+        unsigned i;
 
-	if (ca == NULL || num_cos == 0)
-		return PQOS_RETVAL_PARAM;
+        if (ca == NULL || num_cos == 0)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -576,30 +633,38 @@ pqos_l2ca_set(const unsigned l2id,
                 return ret;
         }
 
-	/**
-	 * Check if class bitmasks are contiguous
-	 */
-	for (i = 0; i < num_cos; i++) {
-		if (!is_contiguous(ca[i].ways_mask)) {
-			LOG_ERROR("L2 COS%u bit mask is not contiguous!\n",
-			          ca[i].class_id);
-			_pqos_api_unlock();
-			return PQOS_RETVAL_PARAM;
-		}
-	}
-	if (m_interface == PQOS_INTER_MSR)
-		ret = hw_l2ca_set(l2id, num_cos, ca);
-	else {
+        /**
+         * Check if class bitmasks are contiguous
+         */
+        for (i = 0; i < num_cos; i++) {
+                int is_contig = 0;
+
+                if (ca[i].cdp) {
+                        is_contig = is_contiguous(ca[i].u.s.data_mask) &&
+                                is_contiguous(ca[i].u.s.code_mask);
+                } else
+                        is_contig = is_contiguous(ca[i].u.ways_mask);
+
+                if (!is_contig) {
+                        LOG_ERROR("L2 COS%u bit mask is not contiguous!\n",
+                                  ca[i].class_id);
+                        _pqos_api_unlock();
+                        return PQOS_RETVAL_PARAM;
+                }
+        }
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_l2ca_set(l2id, num_cos, ca);
+        else {
 #ifdef __linux__
-		ret = os_l2ca_set(l2id, num_cos, ca);
+                ret = os_l2ca_set(l2id, num_cos, ca);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 int
@@ -608,32 +673,64 @@ pqos_l2ca_get(const unsigned l2id,
               unsigned *num_ca,
               struct pqos_l2ca *ca)
 {
-	int ret;
+        int ret;
 
-	if (num_ca == NULL || ca == NULL || max_num_ca == 0)
-		return PQOS_RETVAL_PARAM;
+        if (num_ca == NULL || ca == NULL || max_num_ca == 0)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
-	ret = _pqos_check_init(1);
-	if (ret != PQOS_RETVAL_OK) {
-		_pqos_api_unlock();
-		return ret;
-	}
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
 
-	if (m_interface == PQOS_INTER_MSR)
-		ret = hw_l2ca_get(l2id, max_num_ca, num_ca, ca);
-	else {
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_l2ca_get(l2id, max_num_ca, num_ca, ca);
+        else {
 #ifdef __linux__
-		ret = os_l2ca_get(l2id, max_num_ca, num_ca, ca);
+                ret = os_l2ca_get(l2id, max_num_ca, num_ca, ca);
 #else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
 #endif
         }
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
+}
+
+int
+pqos_l2ca_get_min_cbm_bits(unsigned *min_cbm_bits)
+{
+        int ret;
+
+        if (min_cbm_bits == NULL)
+                return PQOS_RETVAL_PARAM;
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+        if (m_interface == PQOS_INTER_MSR)
+                ret = hw_l2ca_get_min_cbm_bits(min_cbm_bits);
+        else {
+#ifdef __linux__
+                ret = os_l2ca_get_min_cbm_bits(min_cbm_bits);
+#else
+                LOG_INFO("OS interface not supported!\n");
+                ret = PQOS_RETVAL_RESOURCE;
+#endif
+        }
+
+        _pqos_api_unlock();
+
+        return ret;
 }
 
 /*
@@ -643,28 +740,30 @@ pqos_l2ca_get(const unsigned l2id,
  */
 
 int
-pqos_mba_set(const unsigned socket,
+pqos_mba_set(const unsigned mba_id,
              const unsigned num_cos,
              const struct pqos_mba *requested,
              struct pqos_mba *actual)
 {
-	int ret;
-	unsigned i;
+        int ret;
+        unsigned i;
 
-	if (requested == NULL || num_cos == 0)
-		return PQOS_RETVAL_PARAM;
+        if (requested == NULL || num_cos == 0)
+                return PQOS_RETVAL_PARAM;
 
-	/**
-	 * Check if MBA rate is within allowed range
-	 */
-	for (i = 0; i < num_cos; i++)
-		if (requested[i].mb_rate == 0 || requested[i].mb_rate > 100) {
-			LOG_ERROR("MBA COS%u rate out of range (from 1-100)!\n",
-			          requested[i].class_id);
-			return PQOS_RETVAL_PARAM;
-		}
+        /**
+         * Check if MBA rate is within allowed range
+         */
+        for (i = 0; i < num_cos; i++)
+                if (requested[i].ctrl == 0 &&
+                    (requested[i].mb_max == 0 ||
+                     requested[i].mb_max > PQOS_MBA_LINEAR_MAX)) {
+                        LOG_ERROR("MBA COS%u rate out of range (from 1-%d)!\n",
+                                   requested[i].class_id, PQOS_MBA_LINEAR_MAX);
+                        return PQOS_RETVAL_PARAM;
+                }
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -673,30 +772,34 @@ pqos_mba_set(const unsigned socket,
         }
 
         if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mba_set(socket, num_cos, requested, actual);
+                ret = hw_mba_set(mba_id, num_cos, requested, actual);
         else {
+#ifdef __linux__
+                ret = os_mba_set(mba_id, num_cos, requested, actual);
+#else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
+#endif
         }
 
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 
 }
 
 int
-pqos_mba_get(const unsigned socket,
+pqos_mba_get(const unsigned mba_id,
              const unsigned max_num_cos,
              unsigned *num_cos,
              struct pqos_mba *mba_tab)
 {
-	int ret;
+        int ret;
 
-	if (num_cos == NULL || mba_tab == NULL || max_num_cos == 0)
-		return PQOS_RETVAL_PARAM;
+        if (num_cos == NULL || mba_tab == NULL || max_num_cos == 0)
+                return PQOS_RETVAL_PARAM;
 
-	_pqos_api_lock();
+        _pqos_api_lock();
 
         ret = _pqos_check_init(1);
         if (ret != PQOS_RETVAL_OK) {
@@ -705,15 +808,19 @@ pqos_mba_get(const unsigned socket,
         }
 
         if (m_interface == PQOS_INTER_MSR)
-                ret = hw_mba_get(socket, max_num_cos, num_cos, mba_tab);
+                ret = hw_mba_get(mba_id, max_num_cos, num_cos, mba_tab);
         else {
+#ifdef __linux__
+                ret = os_mba_get(mba_id, max_num_cos, num_cos, mba_tab);
+#else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
+#endif
         }
 
-	_pqos_api_unlock();
+        _pqos_api_unlock();
 
-	return ret;
+        return ret;
 }
 
 /*
@@ -738,8 +845,12 @@ pqos_mon_reset(void)
         if (m_interface == PQOS_INTER_MSR)
                 ret = hw_mon_reset();
         else {
+#ifdef __linux__
+                ret = os_mon_reset();
+#else
                 LOG_INFO("OS interface not supported!\n");
                 ret = PQOS_RETVAL_RESOURCE;
+#endif
         }
 
         _pqos_api_unlock();
@@ -815,13 +926,6 @@ pqos_mon_start(const unsigned num_cores,
                 ret = hw_mon_start(num_cores, cores, event, context, group);
         else {
 #ifdef __linux__
-                static int warn = 1;
-                /* Only log warning for first call */
-                if (warn) {
-                        LOG_WARN("As of Kernel 4.10, Intel(R) RDT perf results"
-                                 " per core are found to be incorrect.\n");
-                        warn = 0;
-                }
                 ret = os_mon_start(num_cores, cores, event, context, group);
 #else
                 LOG_INFO("OS interface not supported!\n");
@@ -915,20 +1019,32 @@ pqos_mon_start_pid(const pid_t pid,
                    const enum pqos_mon_event event,
                    void *context,
                    struct pqos_mon_data *group)
+{
+        return pqos_mon_start_pids(1, &pid, event, context, group);
+}
+
+int
+pqos_mon_start_pids(const unsigned num_pids,
+                    const pid_t *pids,
+                    const enum pqos_mon_event event,
+                    void *context,
+                    struct pqos_mon_data *group)
 {
         int ret;
 
-        if (group == NULL || event == 0 || pid < 0)
+        if (num_pids == 0 || pids == NULL || group == NULL || event == 0)
                 return PQOS_RETVAL_PARAM;
 
         if (group->valid == GROUP_VALID_MARKER)
                 return PQOS_RETVAL_PARAM;
 
-        if (m_interface != PQOS_INTER_OS) {
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
                 LOG_ERROR("Incompatible interface "
                           "selected for task monitoring!\n");
                 return PQOS_RETVAL_ERROR;
         }
+
         /**
          * Validate event parameter
          * - only combinations of events allowed
@@ -952,22 +1068,96 @@ pqos_mon_start_pid(const pid_t pid,
                 return ret;
         }
 
-        memset(group, 0, sizeof(*group));
-        group->event = event;
-        group->pid = pid;
-        group->context = context;
-
 #ifdef __linux__
-        ret = os_mon_start_pid(group);
+        ret = os_mon_start_pids(num_pids, pids, event, context, group);
 #else
+        UNUSED_PARAM(context);
         LOG_INFO("OS interface not supported!\n");
         ret = PQOS_RETVAL_RESOURCE;
 #endif
+
         if (ret == PQOS_RETVAL_OK)
                 group->valid = GROUP_VALID_MARKER;
 
         _pqos_api_unlock();
 
         return ret;
+}
 
+int pqos_mon_add_pids(const unsigned num_pids,
+                      const pid_t *pids,
+                      struct pqos_mon_data *group)
+{
+        int ret;
+
+        if (num_pids == 0 || pids == NULL || group == NULL)
+                return PQOS_RETVAL_PARAM;
+
+        if (group->valid != GROUP_VALID_MARKER)
+                return PQOS_RETVAL_PARAM;
+
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+                LOG_ERROR("Incompatible interface "
+                          "selected for task monitoring!\n");
+                return PQOS_RETVAL_ERROR;
+        }
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+#ifdef __linux__
+        ret = os_mon_add_pids(num_pids, pids, group);
+#else
+        LOG_INFO("OS interface not supported!\n");
+        ret = PQOS_RETVAL_RESOURCE;
+#endif
+
+        _pqos_api_unlock();
+
+        return ret;
+}
+
+int pqos_mon_remove_pids(const unsigned num_pids,
+                         const pid_t *pids,
+                         struct pqos_mon_data *group)
+{
+        int ret;
+
+        if (num_pids == 0 || pids == NULL || group == NULL)
+                return PQOS_RETVAL_PARAM;
+
+        if (group->valid != GROUP_VALID_MARKER)
+                return PQOS_RETVAL_PARAM;
+
+        if (m_interface != PQOS_INTER_OS &&
+                m_interface != PQOS_INTER_OS_RESCTRL_MON) {
+                LOG_ERROR("Incompatible interface "
+                          "selected for task monitoring!\n");
+                return PQOS_RETVAL_ERROR;
+        }
+
+        _pqos_api_lock();
+
+        ret = _pqos_check_init(1);
+        if (ret != PQOS_RETVAL_OK) {
+                _pqos_api_unlock();
+                return ret;
+        }
+
+#ifdef __linux__
+        ret = os_mon_remove_pids(num_pids, pids, group);
+#else
+        LOG_INFO("OS interface not supported!\n");
+        ret = PQOS_RETVAL_RESOURCE;
+#endif
+
+        _pqos_api_unlock();
+
+        return ret;
 }
