@@ -66,6 +66,7 @@
 #include "allocation.h"
 #include "monitoring.h"
 
+#include "cpu_registers.h"
 #include "cpuinfo.h"
 #include "machine.h"
 #include "types.h"
@@ -81,31 +82,6 @@
  * ---------------------------------------
  */
 
-/**
- * Available types of allocation resource ID's.
- * (matches CPUID enumeration)
- */
-#define PQOS_RES_ID_L3_ALLOCATION    1       /**< L3 cache allocation */
-#define PQOS_RES_ID_L2_ALLOCATION    2       /**< L2 cache allocation */
-#define PQOS_RES_ID_MB_ALLOCATION    3       /**< Memory BW allocation */
-
-#define PQOS_CPUID_CAT_CDP_BIT       2       /**< CDP supported bit */
-
-#define PQOS_MSR_L3_QOS_CFG          0xC81   /**< L3 CAT config register */
-#define PQOS_MSR_L3_QOS_CFG_CDP_EN   1ULL    /**< L3 CDP enable bit */
-
-#define PQOS_MSR_L3CA_MASK_START     0xC90   /**< L3 CAT class 0 register */
-#define PQOS_MSR_L3CA_MASK_END       0xD0F   /**< L3 CAT class 127 register */
-#define PQOS_MSR_ASSOC               0xC8F   /**< CAT class to core association
-                                                register */
-#define PQOS_MSR_ASSOC_QECOS_SHIFT   32
-#define PQOS_MSR_ASSOC_QECOS_MASK    0xffffffff00000000ULL
-
-#define PQOS_MSR_L2_QOS_CFG          0xC82   /**< L2 CAT config register */
-#define PQOS_MSR_L2_QOS_CFG_CDP_EN   1ULL    /**< L2 CDP enable bit */
-
-#define PQOS_MSR_L2CA_MASK_START     0xC10   /**< L2 CAT class 0 register */
-#define PQOS_MSR_L2CA_MASK_END       0xD8F   /**< L2 CAT class 127 register */
 
 #ifndef LOCKFILE
 #ifdef __linux__
@@ -503,8 +479,8 @@ static int
 l3cdp_is_enabled(const struct pqos_cpuinfo *cpu,
                int *enabled)
 {
-        unsigned *sockets = NULL;
-        unsigned sockets_num = 0, j = 0;
+	unsigned *l3cat_ids = NULL;
+	unsigned l3cat_id_num = 0, j = 0;
         unsigned enabled_num = 0, disabled_num = 0;
         int ret = PQOS_RETVAL_OK;
 
@@ -515,17 +491,17 @@ l3cdp_is_enabled(const struct pqos_cpuinfo *cpu,
         *enabled = 0;
 
         /**
-         * Get list of socket id's
+	 * Get list of l3cat id's
          */
-	sockets = pqos_cpu_get_sockets(cpu, &sockets_num);
-        if (sockets == NULL)
+	l3cat_ids = pqos_cpu_get_l3cat_ids(cpu, &l3cat_id_num);
+	if (l3cat_ids == NULL)
                 return PQOS_RETVAL_RESOURCE;
 
-        for (j = 0; j < sockets_num; j++) {
+	for (j = 0; j < l3cat_id_num; j++) {
                 uint64_t reg = 0;
                 unsigned core = 0;
 
-                ret = pqos_cpu_get_one_core(cpu, sockets[j], &core);
+		ret = pqos_cpu_get_one_by_l3cat_id(cpu, l3cat_ids[j], &core);
                 if (ret != PQOS_RETVAL_OK)
                         goto l3cdp_is_enabled_exit;
 
@@ -542,7 +518,7 @@ l3cdp_is_enabled(const struct pqos_cpuinfo *cpu,
         }
 
         if (disabled_num > 0 && enabled_num > 0) {
-                LOG_ERROR("Inconsistent L3 CDP settings across sockets."
+		LOG_ERROR("Inconsistent L3 CDP settings across l3cat_ids."
                           "Please reset CAT or reboot your system!\n");
                 ret = PQOS_RETVAL_ERROR;
                 goto l3cdp_is_enabled_exit;
@@ -554,8 +530,8 @@ l3cdp_is_enabled(const struct pqos_cpuinfo *cpu,
         LOG_INFO("L3 CDP is %s\n", (*enabled) ? "enabled" : "disabled");
 
  l3cdp_is_enabled_exit:
-        if (sockets != NULL)
-                free(sockets);
+	if (l3cat_ids != NULL)
+		free(l3cat_ids);
 
         return ret;
 }
@@ -1077,11 +1053,7 @@ discover_capabilities(struct pqos_cap **p_cap,
         struct pqos_cap_mba *det_mba = NULL;
         struct pqos_cap *_cap = NULL;
         unsigned sz = 0;
-        int ret = PQOS_RETVAL_OK;
-
-        if (inter != PQOS_INTER_MSR && inter != PQOS_INTER_OS &&
-            inter != PQOS_INTER_OS_RESCTRL_MON)
-                return PQOS_RETVAL_PARAM;
+        int ret = PQOS_RETVAL_RESOURCE;
 
         /**
          * Monitoring init
@@ -1295,6 +1267,15 @@ pqos_init(const struct pqos_config *config)
         if (config == NULL)
                 return PQOS_RETVAL_PARAM;
 
+#ifdef __linux__
+        if (config->interface != PQOS_INTER_MSR &&
+            config->interface != PQOS_INTER_OS &&
+            config->interface != PQOS_INTER_OS_RESCTRL_MON)
+#else
+        if (config->interface != PQOS_INTER_MSR)
+#endif
+                return PQOS_RETVAL_PARAM;
+
         environment = getenv("RDT_IFACE");
         if (environment != NULL) {
                 if (strncasecmp(environment, "OS", 2) == 0) {
