@@ -990,40 +990,73 @@ os_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
 }
 
 /*
- * @brief Check if socket is correct
+ * @brief Check if l3cat_id is correct
  *
- * @param [in] socket CPU socket id
+ * @param [in] cpu l3cat id
  * @param [in] cpu CPU information structure from \a pqos_cap_get
  *
  * @return Operations status
  * @retval PQOS_RETVAL_OK on success
  */
 static int
-verify_socket_id(const unsigned socket, const struct pqos_cpuinfo *cpu)
+verify_l3cat_id(const unsigned l3cat_id, const struct pqos_cpuinfo *cpu)
 {
-        int ret = PQOS_RETVAL_PARAM;
-        unsigned i;
-        unsigned sockets_num;
-        unsigned *sockets;
+	int ret = PQOS_RETVAL_PARAM;
+	unsigned i;
+	unsigned l3cat_num;
+	unsigned *l3cat_ids;
 
-        /* Get socket ids in the system */
-        sockets = pqos_cpu_get_sockets(cpu, &sockets_num);
-        if (sockets == NULL)
-                return PQOS_RETVAL_ERROR;
+	/* Get l3cat ids in the system */
+	l3cat_ids = pqos_cpu_get_l3cat_ids(cpu, &l3cat_num);
+	if (l3cat_ids == NULL)
+		return PQOS_RETVAL_ERROR;
 
-        for (i = 0; i < sockets_num; ++i)
-                if (socket == sockets[i]) {
-                        ret = PQOS_RETVAL_OK;
-                        break;
-                }
+	for (i = 0; i < l3cat_num; ++i)
+		if (l3cat_id == l3cat_ids[i]) {
+			ret = PQOS_RETVAL_OK;
+			break;
+		}
 
-        free(sockets);
+	free(l3cat_ids);
 
-        return ret;
+	return ret;
+}
+
+/*
+ * @brief Check if mba_id is correct
+ *
+ * @param [in] mba_id MBA resource id
+ * @param [in] CPU information structure from \a pqos_cap_get
+ *
+ * @return Operations status
+ * @retval PQOS_RETVAL_OK on success
+ */
+static int
+verify_mba_id(const unsigned mba_id, const struct pqos_cpuinfo *cpu)
+{
+	int ret = PQOS_RETVAL_PARAM;
+	unsigned i;
+	unsigned mba_id_num;
+	unsigned *mba_ids;
+
+	/* Get mba ids in the system */
+	mba_ids = pqos_cpu_get_mba_ids(cpu, &mba_id_num);
+	if (mba_ids == NULL)
+		return PQOS_RETVAL_ERROR;
+
+	for (i = 0; i < mba_id_num; ++i)
+		if (mba_id == mba_ids[i]) {
+			ret = PQOS_RETVAL_OK;
+			break;
+		}
+
+	free(mba_ids);
+
+	return ret;
 }
 
 int
-os_l3ca_set(const unsigned socket,
+os_l3ca_set(const unsigned l3cat_id,
             const unsigned num_cos,
             const struct pqos_l3ca *ca)
 {
@@ -1050,7 +1083,7 @@ os_l3ca_set(const unsigned socket,
 	if (num_cos > num_grps)
 		return PQOS_RETVAL_ERROR;
 
-        ret = verify_socket_id(socket, cpu);
+	ret = verify_l3cat_id(l3cat_id, cpu);
         if (ret != PQOS_RETVAL_OK)
                 goto os_l3ca_set_exit;
 
@@ -1092,7 +1125,7 @@ os_l3ca_set(const unsigned socket,
 			} else
 				l3ca = ca[i];
 
-                        ret = resctrl_schemata_l3ca_set(schmt, socket, &l3ca);
+			ret = resctrl_schemata_l3ca_set(schmt, l3cat_id, &l3ca);
                 }
 
 		/* write schemata */
@@ -1114,7 +1147,7 @@ os_l3ca_set(const unsigned socket,
 }
 
 int
-os_l3ca_get(const unsigned socket,
+os_l3ca_get(const unsigned l3cat_id,
             const unsigned max_num_ca,
             unsigned *num_ca,
             struct pqos_l3ca *ca)
@@ -1142,7 +1175,7 @@ os_l3ca_get(const unsigned socket,
 	if (count > max_num_ca)
 		return PQOS_RETVAL_ERROR;
 
-        ret = verify_socket_id(socket, cpu);
+	ret = verify_l3cat_id(l3cat_id, cpu);
         if (ret != PQOS_RETVAL_OK)
                 goto os_l3ca_get_exit;
 
@@ -1161,7 +1194,7 @@ os_l3ca_get(const unsigned socket,
                         ret = resctrl_alloc_schemata_read(class_id, schmt);
 
                 if (ret == PQOS_RETVAL_OK)
-                        ret = resctrl_schemata_l3ca_get(schmt, socket,
+			ret = resctrl_schemata_l3ca_get(schmt, l3cat_id,
                                                         &ca[class_id]);
 
                 ca[class_id].class_id = class_id;
@@ -1447,7 +1480,7 @@ os_l2ca_get_min_cbm_bits(unsigned *min_cbm_bits)
 }
 
 int
-os_mba_set(const unsigned socket,
+os_mba_set(const unsigned mba_id,
            const unsigned num_cos,
            const struct pqos_mba *requested,
            struct pqos_mba *actual)
@@ -1490,7 +1523,7 @@ os_mba_set(const unsigned socket,
 			return PQOS_RETVAL_PARAM;
 		}
 
-        ret = verify_socket_id(socket, cpu);
+	ret = verify_mba_id(mba_id, cpu);
         if (ret != PQOS_RETVAL_OK)
                 goto os_mba_set_exit;
 
@@ -1537,7 +1570,7 @@ os_mba_set(const unsigned socket,
                                         mba.mb_max = step;
 			}
 
-                        ret = resctrl_schemata_mba_set(schmt, socket, &mba);
+			ret = resctrl_schemata_mba_set(schmt, mba_id, &mba);
                 }
 
                 /* write schemata */
@@ -1553,7 +1586,7 @@ os_mba_set(const unsigned socket,
 
 			/* update actual schemata */
                         if (ret == PQOS_RETVAL_OK) {
-                                ret = resctrl_schemata_mba_get(schmt, socket,
+				ret = resctrl_schemata_mba_get(schmt, mba_id,
                                                                &actual[i]);
                                 actual[i].class_id = requested[i].class_id;
                         }
@@ -1572,7 +1605,7 @@ os_mba_set(const unsigned socket,
 }
 
 int
-os_mba_get(const unsigned socket,
+os_mba_get(const unsigned mba_id,
            const unsigned max_num_cos,
            unsigned *num_cos,
            struct pqos_mba *mba_tab)
@@ -1604,7 +1637,7 @@ os_mba_get(const unsigned socket,
 	if (count > max_num_cos)
 		return PQOS_RETVAL_ERROR;
 
-        ret = verify_socket_id(socket, cpu);
+	ret = verify_mba_id(mba_id, cpu);
         if (ret != PQOS_RETVAL_OK)
                 goto os_mba_get_exit;
 
@@ -1623,8 +1656,8 @@ os_mba_get(const unsigned socket,
 			ret = resctrl_alloc_schemata_read(class_id, schmt);
 
 		if (ret == PQOS_RETVAL_OK)
-                        ret = resctrl_schemata_mba_get(schmt, socket,
-                                                       &mba_tab[class_id]);
+			ret = resctrl_schemata_mba_get(schmt, mba_id,
+						       &mba_tab[class_id]);
 
                 mba_tab[class_id].class_id = class_id;
 
