@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2017 Intel Corporation. All rights reserved.
+ * Copyright(c) 2017-2019 Intel Corporation. All rights reserved.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -51,7 +51,6 @@
  * Local data structures
  * ---------------------------------------
  */
-static const struct pqos_cap *m_cap = NULL;
 static const struct pqos_cpuinfo *m_cpu = NULL;
 
 /** List of non virtual events */
@@ -319,7 +318,7 @@ poll_events(struct pqos_mon_data *group)
                                 group->values.mbm_local_delta;
         }
         if (group->event & PQOS_PERF_EVENT_IPC) {
-                if (group->values.ipc_unhalted > 0)
+                if (group->values.ipc_unhalted_delta > 0)
                         group->values.ipc =
                                 (double)group->values.ipc_retired_delta /
                                 (double)group->values.ipc_unhalted_delta;
@@ -339,6 +338,9 @@ os_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
 {
         unsigned ret;
 
+        ASSERT(cpu != NULL);
+        ASSERT(cap != NULL);
+
 	if (cpu == NULL || cap == NULL)
 		return PQOS_RETVAL_PARAM;
 
@@ -349,7 +351,6 @@ os_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
         if (ret != PQOS_RETVAL_OK)
                 return ret;
 
-        m_cap = cap;
 	m_cpu = cpu;
 
         return ret;
@@ -358,7 +359,6 @@ os_mon_init(const struct pqos_cpuinfo *cpu, const struct pqos_cap *cap)
 int
 os_mon_fini(void)
 {
-        m_cap = NULL;
         m_cpu = NULL;
 
         perf_mon_fini();
@@ -409,55 +409,28 @@ os_mon_start(const unsigned num_cores,
 {
         unsigned i = 0;
         int ret;
+        const struct pqos_cap *cap;
+        const struct pqos_cpuinfo *cpu;
 
         ASSERT(group != NULL);
         ASSERT(cores != NULL);
         ASSERT(num_cores > 0);
         ASSERT(event > 0);
-        ASSERT(m_cpu != NULL);
-        ASSERT(m_cap != NULL);
 
-        static int warn = 1;
-
-        if (warn) {
-                const struct pqos_capability *monitoring_cap = NULL;
-                int resctrl_monitoring_supported = 0;
-
-                /* Only log warning for first call */
-                warn = 0;
-
-                ret = pqos_cap_get_type(m_cap, PQOS_CAP_TYPE_MON,
-                                        &monitoring_cap);
-                if (ret != PQOS_RETVAL_OK)
-                        return ret;
-
-                for (i = 0; i < monitoring_cap->u.mon->num_events; i++) {
-                        if (monitoring_cap->u.mon->events[i].os_support
-                            == PQOS_OS_MON_RESCTRL) {
-                                resctrl_monitoring_supported = 1;
-                                break;
-                        }
-                }
-
-                if (!resctrl_monitoring_supported)
-                        LOG_WARN("As of Kernel 4.10, Intel(R) RDT perf "
-                                 "results per core are found to be "
-                                 "incorrect.\n");
-
-        }
+        _pqos_cap_get(&cap, &cpu);
 
         /**
          * Validate if event is listed in capabilities
          */
         for (i = 0; i < (sizeof(event) * 8); i++) {
                 const enum pqos_mon_event evt_mask =
-                        (enum pqos_mon_event)(1 << i);
+                        (enum pqos_mon_event)(1U << i);
                 const struct pqos_monitor *ptr = NULL;
 
                 if (!(evt_mask & event))
                         continue;
 
-                ret = pqos_cap_get_event(m_cap, evt_mask, &ptr);
+                ret = pqos_cap_get_event(cap, evt_mask, &ptr);
                 if (ret != PQOS_RETVAL_OK || ptr == NULL)
                         return PQOS_RETVAL_PARAM;
         }
@@ -468,7 +441,7 @@ os_mon_start(const unsigned num_cores,
         for (i = 0; i < num_cores; i++) {
                 const unsigned lcore = cores[i];
 
-                ret = pqos_cpu_check_core(m_cpu, lcore);
+                ret = pqos_cpu_check_core(cpu, lcore);
                 if (ret != PQOS_RETVAL_OK)
                         return PQOS_RETVAL_PARAM;
         }
@@ -498,7 +471,7 @@ os_mon_start(const unsigned num_cores,
  * @brief Check if \a tid is in \a tid_map
  *
  * @param[in] tid TID number to search for
- * @param[in] tid_nr lenght of \a tid_map
+ * @param[in] tid_nr length of \a tid_map
  * @param[in] tid_map list of TIDs
  *
  * @retval 1 if found
@@ -522,7 +495,7 @@ tid_exists(const pid_t tid, const unsigned tid_nr, const pid_t *tid_map)
  * @brief Add TID to \a tid_map
  *
  * @param[in] tid TID number to add
- * @param[in] tid_nr lenght of \a tid_map
+ * @param[in] tid_nr length of \a tid_map
  * @param[in] tid_map list of TIDs
  *
  * @return Operational status
@@ -591,6 +564,9 @@ tid_find(const pid_t pid, unsigned *tid_nr, pid_t **tid_map)
                                 break;
                 }
 
+        for (i = 0; i < num_tasks; i++)
+                free(namelist[i]);
+
         free(namelist);
 
         return ret;
@@ -921,23 +897,18 @@ int
 os_mon_poll(struct pqos_mon_data **groups,
               const unsigned num_groups)
 {
-        int ret = PQOS_RETVAL_OK;
         unsigned i = 0;
 
         ASSERT(groups != NULL);
         ASSERT(num_groups > 0);
 
         for (i = 0; i < num_groups; i++) {
-                /**
-                 * If monitoring core/PID then read
-                 * counter values
-                 */
-                ret = poll_events(groups[i]);
+                int ret = poll_events(groups[i]);
+
                 if (ret != PQOS_RETVAL_OK)
-                        LOG_WARN("Failed to read event on "
+                        LOG_WARN("Failed to poll event on "
                                  "group number %u\n", i);
         }
 
         return PQOS_RETVAL_OK;
 }
-
