@@ -39,17 +39,19 @@
 #include "resctrl_utils.h"
 #include "types.h"
 
-
 /*
  * @brief Structure to hold parsed schemata
  */
 struct resctrl_schemata {
-        unsigned l3ids_num;     /**< Number of L3 */
+        unsigned l3ids_num; /**< Number of L3 */
         unsigned *l3ids;
         struct pqos_l3ca *l3ca; /**< L3 COS definitions */
-        struct pqos_mba *mba;   /**< MBA COS definitions */
 
-        unsigned l2ids_num;     /**< Number of L2 clusters */
+        unsigned mbaids_num; /**< Number of mba ids */
+        unsigned *mbaids;
+        struct pqos_mba *mba; /**< MBA COS definitions */
+
+        unsigned l2ids_num; /**< Number of L2 clusters */
         unsigned *l2ids;
         struct pqos_l2ca *l2ca; /**< L2 COS definitions */
 };
@@ -70,6 +72,8 @@ resctrl_schemata_free(struct resctrl_schemata *schemata)
                 free(schemata->l2ids);
         if (schemata->l3ids != NULL)
                 free(schemata->l3ids);
+        if (schemata->mbaids != NULL)
+                free(schemata->mbaids);
         free(schemata);
 }
 
@@ -95,8 +99,8 @@ resctrl_schemata_alloc(const struct pqos_cap *cap,
                 if (schemata->l2ids == NULL)
                         goto resctrl_schemata_alloc_error;
 
-                schemata->l2ca = calloc(schemata->l2ids_num,
-                                        sizeof(struct pqos_l2ca));
+                schemata->l2ca =
+                    calloc(schemata->l2ids_num, sizeof(struct pqos_l2ca));
                 if (schemata->l2ca == NULL)
                         goto resctrl_schemata_alloc_error;
         }
@@ -104,13 +108,13 @@ resctrl_schemata_alloc(const struct pqos_cap *cap,
         /* L3 */
         retval = pqos_cap_get_type(cap, PQOS_CAP_TYPE_L3CA, &cap_l3ca);
         if (retval == PQOS_RETVAL_OK && cap_l3ca != NULL) {
-                schemata->l3ids = pqos_cpu_get_sockets(cpu,
-                                                       &schemata->l3ids_num);
+                schemata->l3ids =
+                    pqos_cpu_get_l3cat_ids(cpu, &schemata->l3ids_num);
                 if (schemata->l3ids == NULL)
                         goto resctrl_schemata_alloc_error;
 
-                schemata->l3ca = calloc(schemata->l3ids_num,
-                                        sizeof(struct pqos_l3ca));
+                schemata->l3ca =
+                    calloc(schemata->l3ids_num, sizeof(struct pqos_l3ca));
                 if (schemata->l3ca == NULL)
                         goto resctrl_schemata_alloc_error;
         }
@@ -120,15 +124,15 @@ resctrl_schemata_alloc(const struct pqos_cap *cap,
         if (retval == PQOS_RETVAL_OK && cap_mba != NULL) {
                 int ctrl_enabled;
 
-                if (schemata->l3ids == NULL) {
-                        schemata->l3ids = pqos_cpu_get_sockets(cpu,
-                                &schemata->l3ids_num);
-                        if (schemata->l3ids == NULL)
+                if (schemata->mbaids == NULL) {
+                        schemata->mbaids =
+                            pqos_cpu_get_mba_ids(cpu, &schemata->mbaids_num);
+                        if (schemata->mbaids == NULL)
                                 goto resctrl_schemata_alloc_error;
                 }
 
-                schemata->mba = calloc(schemata->l3ids_num,
-                                       sizeof(struct pqos_mba));
+                schemata->mba =
+                    calloc(schemata->mbaids_num, sizeof(struct pqos_mba));
                 if (schemata->mba == NULL)
                         goto resctrl_schemata_alloc_error;
 
@@ -137,13 +141,13 @@ resctrl_schemata_alloc(const struct pqos_cap *cap,
                         goto resctrl_schemata_alloc_error;
 
                 /* fill ctrl and class_id */
-                for (i = 0; i < schemata->l3ids_num; i++)
+                for (i = 0; i < schemata->mbaids_num; i++)
                         schemata->mba[i].ctrl = ctrl_enabled;
         }
 
         return schemata;
 
- resctrl_schemata_alloc_error:
+resctrl_schemata_alloc_error:
         resctrl_schemata_free(schemata);
         return NULL;
 }
@@ -194,10 +198,10 @@ resctrl_schemata_reset(struct resctrl_schemata *schmt,
 
                 /* kernel always rounds up value to MBA granularity */
                 if (mba_cap->ctrl_on)
-                        default_mba = UINT32_MAX -
-                                UINT32_MAX % mba_cap->throttle_step;
+                        default_mba =
+                            UINT32_MAX - UINT32_MAX % mba_cap->throttle_step;
 
-                for (j = 0; j < schmt->l3ids_num; j++)
+                for (j = 0; j < schmt->mbaids_num; j++)
                         schmt->mba[j].mb_max = default_mba;
         }
 
@@ -312,6 +316,20 @@ resctrl_schemata_l3ca_set(struct resctrl_schemata *schemata,
         return PQOS_RETVAL_OK;
 }
 
+static int
+get_mba_index(const struct resctrl_schemata *schemata, unsigned resource_id)
+{
+        unsigned i;
+
+        ASSERT(schemata->mbaids != NULL);
+
+        for (i = 0; i < schemata->mbaids_num; ++i)
+                if (schemata->mbaids[i] == resource_id)
+                        return i;
+
+        return -1;
+}
+
 int
 resctrl_schemata_mba_get(const struct resctrl_schemata *schemata,
                          unsigned resource_id,
@@ -323,7 +341,7 @@ resctrl_schemata_mba_get(const struct resctrl_schemata *schemata,
         ASSERT(ca != NULL);
         ASSERT(schemata->mba != NULL);
 
-        index = get_l3_index(schemata, resource_id);
+        index = get_mba_index(schemata, resource_id);
         if (index < 0)
                 return PQOS_RETVAL_ERROR;
 
@@ -343,7 +361,7 @@ resctrl_schemata_mba_set(struct resctrl_schemata *schemata,
         ASSERT(ca != NULL);
         ASSERT(schemata->mba != NULL);
 
-        index = get_l3_index(schemata, resource_id);
+        index = get_mba_index(schemata, resource_id);
         if (index < 0)
                 return PQOS_RETVAL_ERROR;
 
@@ -424,9 +442,11 @@ resctrl_schemata_set(const unsigned res_id,
         case RESCTRL_SCHEMATA_TYPE_L3:
         case RESCTRL_SCHEMATA_TYPE_L3CODE:
         case RESCTRL_SCHEMATA_TYPE_L3DATA:
-        case RESCTRL_SCHEMATA_TYPE_MB:
                 index = get_l3_index(schemata, res_id);
                 break;
+        case RESCTRL_SCHEMATA_TYPE_MB:
+                index = get_mba_index(schemata, res_id);
+                break;
         }
 
         if (index < 0)
@@ -505,12 +525,12 @@ resctrl_schemata_read(FILE *fd, struct resctrl_schemata *schemata)
                 /**
                  * Parse COS masks
                  */
-                for (++p; ; p = NULL) {
+                for (++p;; p = NULL) {
                         char *token = NULL;
                         uint64_t id = 0;
                         uint64_t value = 0;
-                        unsigned base = (type == RESCTRL_SCHEMATA_TYPE_MB
-                                         ? 10 : 16);
+                        unsigned base =
+                            (type == RESCTRL_SCHEMATA_TYPE_MB ? 10 : 16);
 
                         token = strtok_r(p, ";", &saveptr);
                         if (token == NULL)
@@ -537,7 +557,7 @@ resctrl_schemata_read(FILE *fd, struct resctrl_schemata *schemata)
                 }
         }
 
- resctrl_schemata_read_exit:
+resctrl_schemata_read_exit:
         if (buf != NULL)
                 free(buf);
 
@@ -553,11 +573,13 @@ resctrl_schemata_write(FILE *fd, const struct resctrl_schemata *schemata)
         if (schemata->l2ca != NULL && !schemata->l2ca[0].cdp) {
                 fprintf(fd, "L2:");
                 for (i = 0; i < schemata->l2ids_num; i++) {
+                        unsigned id = schemata->l2ids[i];
+                        unsigned long long mask =
+                            (unsigned long long)schemata->l2ca[i].u.ways_mask;
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%llx",
-                                schemata->l2ids[i], (unsigned long long)
-                                schemata->l2ca[i].u.ways_mask);
+                        fprintf(fd, "%u=%llx", id, mask);
                 }
                 fprintf(fd, "\n");
         }
@@ -566,19 +588,23 @@ resctrl_schemata_write(FILE *fd, const struct resctrl_schemata *schemata)
         if (schemata->l2ca != NULL && schemata->l2ca[0].cdp) {
                 fprintf(fd, "L2CODE:");
                 for (i = 0; i < schemata->l2ids_num; i++) {
+                        unsigned id = schemata->l2ids[i];
+                        unsigned long long mask =
+                            (unsigned long long)schemata->l2ca[i].u.s.code_mask;
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%llx",
-                                schemata->l2ids[i], (unsigned long long)
-                                schemata->l2ca[i].u.s.code_mask);
+                        fprintf(fd, "%u=%llx", id, mask);
                 }
                 fprintf(fd, "\nL2DATA:");
                 for (i = 0; i < schemata->l2ids_num; i++) {
+                        unsigned id = schemata->l2ids[i];
+                        unsigned long long mask =
+                            (unsigned long long)schemata->l2ca[i].u.s.data_mask;
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%llx",
-                                schemata->l2ids[i], (unsigned long long)
-                                schemata->l2ca[i].u.s.data_mask);
+                        fprintf(fd, "%u=%llx", id, mask);
                 }
                 fprintf(fd, "\n");
         }
@@ -587,11 +613,13 @@ resctrl_schemata_write(FILE *fd, const struct resctrl_schemata *schemata)
         if (schemata->l3ca != NULL && !schemata->l3ca[0].cdp) {
                 fprintf(fd, "L3:");
                 for (i = 0; i < schemata->l3ids_num; i++) {
+                        unsigned id = schemata->l3ids[i];
+                        unsigned long long mask =
+                            (unsigned long long)schemata->l3ca[i].u.ways_mask;
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%llx",
-                                schemata->l3ids[i], (unsigned long long)
-                                schemata->l3ca[i].u.ways_mask);
+                        fprintf(fd, "%u=%llx", id, mask);
                 }
                 fprintf(fd, "\n");
         }
@@ -600,19 +628,23 @@ resctrl_schemata_write(FILE *fd, const struct resctrl_schemata *schemata)
         if (schemata->l3ca != NULL && schemata->l3ca[0].cdp) {
                 fprintf(fd, "L3CODE:");
                 for (i = 0; i < schemata->l3ids_num; i++) {
+                        unsigned id = schemata->l3ids[i];
+                        unsigned long long mask =
+                            (unsigned long long)schemata->l3ca[i].u.s.code_mask;
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%llx",
-                                schemata->l3ids[i], (unsigned long long)
-                                schemata->l3ca[i].u.s.code_mask);
+                        fprintf(fd, "%u=%llx", id, mask);
                 }
                 fprintf(fd, "\nL3DATA:");
                 for (i = 0; i < schemata->l3ids_num; i++) {
+                        unsigned id = schemata->l3ids[i];
+                        unsigned long long mask =
+                            (unsigned long long)schemata->l3ca[i].u.s.data_mask;
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%llx",
-                                schemata->l3ids[i], (unsigned long long)
-                                schemata->l3ca[i].u.s.data_mask);
+                        fprintf(fd, "%u=%llx", id, mask);
                 }
                 fprintf(fd, "\n");
         }
@@ -620,11 +652,12 @@ resctrl_schemata_write(FILE *fd, const struct resctrl_schemata *schemata)
         /* MBA */
         if (schemata->mba != NULL) {
                 fprintf(fd, "MB:");
-                for (i = 0; i < schemata->l3ids_num; i++) {
+                for (i = 0; i < schemata->mbaids_num; i++) {
+                        unsigned id = schemata->mbaids[i];
+
                         if (i > 0)
                                 fprintf(fd, ";");
-                        fprintf(fd, "%u=%u", schemata->l3ids[i],
-                                schemata->mba[i].mb_max);
+                        fprintf(fd, "%u=%u", id, schemata->mba[i].mb_max);
                 }
                 fprintf(fd, "\n");
         }
