@@ -66,6 +66,81 @@ _pqos_utils_init(int interface)
         return PQOS_RETVAL_OK;
 }
 
+unsigned *
+pqos_cpu_get_mba_ids(const struct pqos_cpuinfo *cpu,
+		     unsigned *count)
+{
+	unsigned mba_id_count = 0, i = 0;
+	unsigned *mba_ids = NULL;
+
+	ASSERT(cpu != NULL);
+	ASSERT(count != NULL);
+	if (cpu == NULL || count == NULL)
+		return NULL;
+
+	mba_ids = (unsigned *) malloc(sizeof(mba_ids[0]) * cpu->num_cores);
+	if (mba_ids == NULL)
+		return NULL;
+
+	for (i = 0; i < cpu->num_cores; i++) {
+		unsigned j = 0;
+
+		/**
+		 * Check if this mba id is already on the \a mbas list
+		 */
+		for (j = 0; j < mba_id_count && mba_id_count > 0; j++)
+			if (cpu->cores[i].mba_id  == mba_ids[j])
+				break;
+
+		if (j >= mba_id_count || mba_id_count == 0) {
+			/**
+			 * This mba_id wasn't reported before
+			 */
+			mba_ids[mba_id_count++] = cpu->cores[i].mba_id;
+		}
+	}
+
+	*count = mba_id_count;
+	return mba_ids;
+}
+
+unsigned *
+pqos_cpu_get_l3cat_ids(const struct pqos_cpuinfo *cpu,
+		       unsigned *count)
+{
+	unsigned l3cat_count = 0, i = 0;
+	unsigned *l3cat_ids = NULL;
+
+	ASSERT(cpu != NULL);
+	ASSERT(count != NULL);
+	if (cpu == NULL || count == NULL)
+		return NULL;
+
+	l3cat_ids = (unsigned *) malloc(sizeof(l3cat_ids[0]) * cpu->num_cores);
+	if (l3cat_ids == NULL)
+		return NULL;
+
+	for (i = 0; i < cpu->num_cores; i++) {
+		unsigned j = 0;
+
+		/**
+		 * Check if this l3cat id is already on the \a l3cat_ids list
+		 */
+		for (j = 0; j < l3cat_count && l3cat_count > 0; j++)
+			if (cpu->cores[i].l3cat_id  == l3cat_ids[j])
+				break;
+
+		if (j >= l3cat_count || l3cat_count == 0) {
+			/**
+			 * This l3cat_id wasn't reported before
+			 */
+			l3cat_ids[l3cat_count++] = cpu->cores[i].l3cat_id;
+		}
+	}
+
+	*count = l3cat_count;
+	return l3cat_ids;
+}
 
 unsigned *
 pqos_cpu_get_sockets(const struct pqos_cpuinfo *cpu,
@@ -270,6 +345,50 @@ pqos_cpu_get_one_core(const struct pqos_cpuinfo *cpu,
         return PQOS_RETVAL_ERROR;
 }
 
+int
+pqos_cpu_get_one_by_l3cat_id(const struct pqos_cpuinfo *cpu,
+			      const unsigned l3cat_id,
+			      unsigned *lcore)
+{
+	unsigned i = 0;
+
+	ASSERT(cpu != NULL);
+	ASSERT(lcore != NULL);
+
+	if (cpu == NULL || lcore == NULL)
+		return PQOS_RETVAL_PARAM;
+
+	for (i = 0; i < cpu->num_cores; i++)
+		if (cpu->cores[i].l3cat_id == l3cat_id) {
+			*lcore = cpu->cores[i].lcore;
+			return PQOS_RETVAL_OK;
+		}
+
+	return PQOS_RETVAL_ERROR;
+}
+
+int
+pqos_cpu_get_one_by_mba_id(const struct pqos_cpuinfo *cpu,
+			    const unsigned mba_id,
+			    unsigned *lcore)
+{
+	unsigned i = 0;
+
+	ASSERT(cpu != NULL);
+	ASSERT(lcore != NULL);
+
+	if (cpu == NULL || lcore == NULL)
+		return PQOS_RETVAL_PARAM;
+
+	for (i = 0; i < cpu->num_cores; i++)
+		if (cpu->cores[i].mba_id == mba_id) {
+			*lcore = cpu->cores[i].lcore;
+			return PQOS_RETVAL_OK;
+		}
+
+	return PQOS_RETVAL_ERROR;
+}
+
 int
 pqos_cpu_get_one_by_l2id(const struct pqos_cpuinfo *cpu,
                          const unsigned l2id,
