@@ -439,12 +439,12 @@ set_allocation_cos(char *str, unsigned *res_ids,
         parse_cos_mask_type(str, &update_scope, &class_id);
         mask = strtouint64(p+1);
 
-	/* if MBA selected, set MBA classes */
+        /* if MBA selected, set MBA classes */
         if (type == MBA || type == MBA_CTRL) {
                 int ctrl = (type == MBA_CTRL) ? 1 : 0;
 
                 if (ids == NULL)
-                        ids = pqos_cpu_get_sockets(cpu, &n);
+                        ids = pqos_cpu_get_mba_ids(cpu, &n);
                 if (ids == NULL) {
                         printf("Failed to retrieve socket info!\n");
                         return -1;
@@ -470,7 +470,7 @@ set_allocation_cos(char *str, unsigned *res_ids,
         }
         /* set L3 CAT classes */
         if (ids == NULL)
-                ids = pqos_cpu_get_sockets(cpu, &n);
+                ids = pqos_cpu_get_l3cat_ids(cpu, &n);
         if (ids == NULL) {
                 printf("Failed to retrieve socket info!\n");
                 return -1;
@@ -514,14 +514,14 @@ set_allocation_class(char *str, const struct pqos_cpuinfo *cpu)
         /**
          * Set up selected res_ids table
          */
-	q = strchr(str, '@');
-	if (q != NULL) {
+        q = strchr(str, '@');
+        if (q != NULL) {
                 uint64_t ids[max_res_sz];
                 /**
                  * Socket ID's selected - set up res_ids table
                  */
                 *p = '\0';
-		*q = '\0';
+                *q = '\0';
                 n = strlisttotab(++q, ids, DIM(ids));
                 if (n == 0) {
                         printf("No resource ID specified: %s\n", s);
@@ -538,12 +538,12 @@ set_allocation_class(char *str, const struct pqos_cpuinfo *cpu)
                         res_ids[i] = (unsigned)ids[i];
                 }
                 sp = res_ids;
-	} else
+        } else
                 *p = '\0';
         /**
-	 * Determine selected type (L3/L2/MBA/MBA CTRL)
-	 */
-	if (strcasecmp(str, "llc") == 0)
+         * Determine selected type (L3/L2/MBA/MBA CTRL)
+         */
+        if (strcasecmp(str, "llc") == 0)
                 type = L3CA;
         else if (strcasecmp(str, "l2") == 0)
                 type = L2CA;
@@ -552,7 +552,7 @@ set_allocation_class(char *str, const struct pqos_cpuinfo *cpu)
         else if (strcasecmp(str, "mba_max") == 0)
                 type = MBA_CTRL;
         else {
-		printf("Unrecognized allocation type: %s\n", s);
+                printf("Unrecognized allocation type: %s\n", s);
                 free(s);
                 return ret;
         }
@@ -1057,13 +1057,18 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                         const struct pqos_capability *cap_l3ca,
                         const struct pqos_capability *cap_l2ca,
                         const struct pqos_capability *cap_mba,
-                        const unsigned sock_count,
-                        const unsigned *sockets,
                         const struct pqos_cpuinfo *cpu_info,
                         const int verbose)
 {
         int ret;
         unsigned i;
+	unsigned sock_count, *sockets = NULL;
+
+	sockets = pqos_cpu_get_sockets(cpu_info, &sock_count);
+	if (sockets == NULL) {
+		printf("Error retrieving information for Sockets\n");
+		return;
+	}
 
         print_per_socket_config(cap_l3ca, cap_mba, sock_count, sockets);
 
@@ -1074,7 +1079,7 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                 l2id = pqos_cpu_get_l2ids(cpu_info, &count);
                 if (l2id == NULL) {
                         printf("Error retrieving information for L2\n");
-                        return;
+			goto free_and_return;
                 }
 
                 for (i = 0; i < count; i++) {
@@ -1103,7 +1108,7 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                 lcores = pqos_cpu_get_cores(cpu_info, sockets[i], &lcount);
                 if (lcores == NULL) {
                         printf("Error retrieving core information!\n");
-                        return;
+			goto free_and_return;
                 }
                 printf("Core information for socket %u:\n",
                        sockets[i]);
@@ -1115,7 +1120,7 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                                 printf("Error retrieving information "
                                        "for core %u!\n", lcores[n]);
                                 free(lcores);
-                                return;
+				goto free_and_return;
                         }
 
                         print_core_assoc((cap_l3ca != NULL) ||
@@ -1127,6 +1132,7 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                 }
                 free(lcores);
         }
+
         if (sel_interface == PQOS_INTER_OS) {
                 unsigned max_cos = UINT_MAX;
 
@@ -1151,7 +1157,7 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                         tasks = pqos_pid_get_pid_assoc(i, &tcount);
                         if (tasks == NULL) {
                                 printf("Error retrieving PID information!\n");
-                                return;
+				goto free_and_return;
                         }
                         printf("    COS%u => ", i);
                         if (tcount == 0)
@@ -1166,11 +1172,16 @@ void alloc_print_config(const struct pqos_capability *cap_mon,
                         free(tasks);
                 }
         }
+
+free_and_return:
+	if (sockets)
+		free(sockets);
+
 }
 
 int alloc_apply(const struct pqos_capability *cap_l3ca,
                 const struct pqos_capability *cap_l2ca,
-		const struct pqos_capability *cap_mba,
+                const struct pqos_capability *cap_mba,
                 const struct pqos_cpuinfo *cpu)
 {
         if (cap_l3ca != NULL || cap_l2ca != NULL || cap_mba != NULL) {
