@@ -82,8 +82,10 @@ class TestRdtsetMba(test.Test):
         else:
             last_cos = Resctrl.get_ctrl_group_count() - 1
 
-        assert re.search("Core 5, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) is not None
-        assert re.search("Core 6, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) is not None
+        assert re.search("Core 5, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) \
+               is not None
+        assert re.search("Core 6, L2ID [0-9]+, L3ID [0-9]+ => COS%d" % last_cos, stdout) \
+               is not None
         assert "MBA COS{} => 50% available".format(last_cos) in stdout
 
         self.run("killall memtester")
