@@ -59,15 +59,13 @@
  * MACROS
  */
 
-#define UNUSED_PARAM(x) (void)(x)
-
 #ifdef __linux__
-#define PAGE_SIZE       (4 * 1024)
+#define PAGE_SIZE (4 * 1024)
 #endif
 
-#define MEMCHUNK_SIZE   (PAGE_SIZE * 32 * 1024) /* 128MB chunk */
-#define CL_SIZE         (64)
-#define CHUNKS          (128)
+#define MEMCHUNK_SIZE (PAGE_SIZE * 32 * 1024) /* 128MB chunk */
+#define CL_SIZE (64)
+#define CHUNKS (128)
 
 #ifdef DEBUG
 #include <assert.h>
@@ -77,9 +75,14 @@
 #define ALWAYS_INLINE static inline __attribute__((always_inline))
 #endif
 
-#define MAX_OPTARG_LEN  64
+#define MAX_OPTARG_LEN 64
+
+#define MAX_MEM_BW 100 * 1000 /* 100GBps */
+
+#define CPU_FEATURE_SSE4_2 (1ULL << 0)
+#define CPU_FEATURE_CLWB (1ULL << 1)
+#define CPU_FEATURE_AVX512F (1ULL << 2)
 
-#define MAX_MEM_BW      100 * 1000 /* 100GBps */
 /**
  * DATA STRUCTURES
  */
@@ -98,18 +101,35 @@ enum cl_type {
         CL_TYPE_READ_WB,
         CL_TYPE_READ_WB_DQA,
         CL_TYPE_READ_MOD_WRITE,
+#ifdef __x86_64__
         CL_TYPE_WRITE_DQA,
         CL_TYPE_WRITE_DQA_FLUSH,
+#endif
         CL_TYPE_WRITE_WB,
+#ifdef __x86_64__
         CL_TYPE_WRITE_WB_AVX512,
+#endif
         CL_TYPE_WRITE_WB_CLWB,
         CL_TYPE_WRITE_WB_FLUSH,
         CL_TYPE_WRITE_NTI,
         CL_TYPE_WRITE_NTI_CLWB,
+#ifdef __x86_64__
         CL_TYPE_WRITE_NT512,
         CL_TYPE_WRITE_NTDQ
+#endif
 };
 
+/* structure to store cpuid values */
+struct cpuid_out {
+        uint32_t eax;
+        uint32_t ebx;
+        uint32_t ecx;
+        uint32_t edx;
+};
+
+static struct cpuid_out cpuid_1_0; /* leaf 1, sub-leaf 0 */
+static struct cpuid_out cpuid_7_0; /* leaf 7, sub-leaf 0 */
+
 /**
  * COMMON DATA
  */
@@ -122,12 +142,121 @@ static unsigned memchunk_offset = 0;
  * UTILS
  */
 
+/*
+ * A C wrapper for CPUID opcode
+ *
+ * Parameters:
+ *    [in] leaf    - CPUID leaf number (EAX)
+ *    [in] subleaf - CPUID sub-leaf number (ECX)
+ *    [out] out    - registers structure to store results of CPUID into
+ */
+static void
+lcpuid(const unsigned leaf, const unsigned subleaf, struct cpuid_out *out)
+{
+        if (out == NULL)
+                return;
+
+#ifdef __x86_64__
+        asm volatile("mov %4, %%eax\n\t"
+                     "mov %5, %%ecx\n\t"
+                     "cpuid\n\t"
+                     "mov %%eax, %0\n\t"
+                     "mov %%ebx, %1\n\t"
+                     "mov %%ecx, %2\n\t"
+                     "mov %%edx, %3\n\t"
+                     : "=g"(out->eax), "=g"(out->ebx), "=g"(out->ecx),
+                       "=g"(out->edx)
+                     : "g"(leaf), "g"(subleaf)
+                     : "%eax", "%ebx", "%ecx", "%edx");
+#else
+        asm volatile("push %%ebx\n\t"
+                     "mov %4, %%eax\n\t"
+                     "mov %5, %%ecx\n\t"
+                     "cpuid\n\t"
+                     "mov %%eax, %0\n\t"
+                     "mov %%ebx, %1\n\t"
+                     "mov %%ecx, %2\n\t"
+                     "mov %%edx, %3\n\t"
+                     "pop %%ebx\n\t"
+                     : "=g"(out->eax), "=g"(out->ebx), "=g"(out->ecx),
+                       "=g"(out->edx)
+                     : "g"(leaf), "g"(subleaf)
+                     : "%eax", "%ecx", "%edx");
+#endif
+}
+
+static uint32_t
+detect_sse42(void)
+{
+        /* Check presence of SSE4.2 - bit 20 of ECX */
+        return (cpuid_1_0.ecx & (1 << 20));
+}
+
+static uint32_t
+detect_clwb(void)
+{
+        /* Check presence of CLWB - bit 24 of EBX */
+        return (cpuid_7_0.ebx & (1 << 24));
+}
+
+static uint32_t
+detect_avx512f(void)
+{
+        /* Check presence of AVX512F - bit 16 of EBX */
+        return (cpuid_7_0.ebx & (1 << 16));
+}
+
+/**
+ * @brief Function to detect CPU features
+ *
+ * @return Bitmap of supported features
+ */
+static uint64_t
+cpu_feature_detect(void)
+{
+        static const struct {
+                unsigned req_leaf_number;
+                uint64_t feat;
+                uint32_t (*detect_fn)(void);
+        } feat_tab[] = {
+            {1, CPU_FEATURE_SSE4_2, detect_sse42},
+            {7, CPU_FEATURE_CLWB, detect_clwb},
+            {7, CPU_FEATURE_AVX512F, detect_avx512f},
+        };
+        struct cpuid_out r;
+        unsigned hi_leaf_number = 0;
+        uint64_t features = 0;
+        unsigned i;
+
+        /* Get highest supported CPUID leaf number */
+        lcpuid(0x0, 0x0, &r);
+        hi_leaf_number = r.eax;
+
+        /* Get the most common CPUID leafs to speed up the detection */
+        if (hi_leaf_number >= 1)
+                lcpuid(0x1, 0x0, &cpuid_1_0);
+
+        if (hi_leaf_number >= 7)
+                lcpuid(0x7, 0x0, &cpuid_7_0);
+
+        for (i = 0; i < (sizeof(feat_tab) / sizeof(feat_tab[0])); i++) {
+                if (hi_leaf_number < feat_tab[i].req_leaf_number)
+                        continue;
+
+                if (feat_tab[i].detect_fn() != 0)
+                        features |= feat_tab[i].feat;
+        }
+
+        return features;
+}
+
 /**
  * @brief Function to bind thread to a cpu
  *
  * @param cpuid cpu to bind thread to
  */
-static void set_thread_affinity(const unsigned cpuid)
+static void
+set_thread_affinity(const unsigned cpuid)
 {
 #ifdef __linux__
         cpu_set_t cpuset;
@@ -149,7 +278,6 @@ static void set_thread_affinity(const unsigned cpuid)
 #endif
         if (res != 0)
                 perror("Error setting core affinity ");
-
 }
 
 /**
@@ -160,10 +288,7 @@ static void set_thread_affinity(const unsigned cpuid)
 ALWAYS_INLINE void
 cl_flush(void *p)
 {
-        asm volatile("clflush (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
+        asm volatile("clflush (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -172,10 +297,7 @@ cl_flush(void *p)
 ALWAYS_INLINE void
 sb(void)
 {
-        asm volatile("sfence\n\t"
-                     :
-                     :
-                     : "memory");
+        asm volatile("sfence\n\t" : : : "memory");
 }
 
 /**
@@ -186,17 +308,7 @@ sb(void)
 ALWAYS_INLINE void
 cl_wb(void *p)
 {
-#ifdef bit_CLWB
-        asm volatile("clwb (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
-#else
-        UNUSED_PARAM(p);
-
-        printf("clwb instruction is not suported\n");
-        exit(EXIT_FAILURE);
-#endif
+        asm volatile("clwb (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -224,7 +336,8 @@ mem_flush(void *p, size_t s)
  *
  * @retval p allocated memory
  */
-static void *malloc_and_init_memory(size_t s)
+static void *
+malloc_and_init_memory(size_t s)
 {
         void *p = NULL;
         int ret;
@@ -233,7 +346,7 @@ static void *malloc_and_init_memory(size_t s)
 
         if (ret != 0 || p == NULL) {
                 printf("ERROR: Failed to allocate %lu bytes\n",
-                       (unsigned long) s - s % PAGE_SIZE);
+                       (unsigned long)s - s % PAGE_SIZE);
                 stop_loop = 1;
                 return NULL;
         }
@@ -242,7 +355,7 @@ static void *malloc_and_init_memory(size_t s)
         size_t s64 = s / sizeof(uint64_t);
 
         while (s64 > 0) {
-                *p64 = (uint64_t) rand();
+                *p64 = (uint64_t)rand();
                 p64 += (CL_SIZE / sizeof(uint64_t));
                 s64 -= (CL_SIZE / sizeof(uint64_t));
         }
@@ -263,10 +376,7 @@ static void *malloc_and_init_memory(size_t s)
 ALWAYS_INLINE void
 cl_prefetch_t0(void *p)
 {
-        asm volatile("prefetcht0 (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
+        asm volatile("prefetcht0 (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -277,10 +387,7 @@ cl_prefetch_t0(void *p)
 ALWAYS_INLINE void
 cl_prefetch_t1(void *p)
 {
-        asm volatile("prefetcht1 (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
+        asm volatile("prefetcht1 (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -291,10 +398,7 @@ cl_prefetch_t1(void *p)
 ALWAYS_INLINE void
 cl_prefetch_t2(void *p)
 {
-        asm volatile("prefetcht2 (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
+        asm volatile("prefetcht2 (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -305,10 +409,7 @@ cl_prefetch_t2(void *p)
 ALWAYS_INLINE void
 cl_prefetch_nta(void *p)
 {
-        asm volatile("prefetchnta (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
+        asm volatile("prefetchnta (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -319,10 +420,7 @@ cl_prefetch_nta(void *p)
 ALWAYS_INLINE void
 cl_prefetch_w(void *p)
 {
-        asm volatile("prefetchw (%0)\n\t"
-                     :
-                     : "r"(p)
-                     : "memory");
+        asm volatile("prefetchw (%0)\n\t" : : "r"(p) : "memory");
 }
 
 /**
@@ -347,6 +445,7 @@ cl_read_mod_write(void *p, const uint64_t v)
                      : "memory");
 }
 
+#ifdef __x86_64__
 /**
  * @brief WB store vector version
  *
@@ -356,19 +455,11 @@ cl_read_mod_write(void *p, const uint64_t v)
 ALWAYS_INLINE void
 cl_write_avx512(void *p, const uint64_t v)
 {
-#if defined(__x86_64__) && defined(bit_AVX512F)
         asm volatile("vmovq   %0, %%xmm1\n\t"
                      "vmovdqa64 %%zmm1, (%1)\n\t"
                      :
                      : "r"(v), "r"(p)
                      : "%zmm1", "memory");
-#else
-        UNUSED_PARAM(p);
-        UNUSED_PARAM(v);
-
-        printf("Instruction is not suported\n");
-        exit(EXIT_FAILURE);
-#endif
 }
 
 /**
@@ -380,7 +471,6 @@ cl_write_avx512(void *p, const uint64_t v)
 ALWAYS_INLINE void
 cl_write_dqa(void *p, const uint64_t v)
 {
-#ifdef __x86_64__
         asm volatile("movq   %0, %%xmm1\n\t"
                      "movdqa %%xmm1, (%1)\n\t"
                      "movdqa %%xmm1, 16(%1)\n\t"
@@ -389,13 +479,6 @@ cl_write_dqa(void *p, const uint64_t v)
                      :
                      : "r"(v), "r"(p)
                      : "%xmm1", "memory");
-#else
-        UNUSED_PARAM(p);
-        UNUSED_PARAM(v);
-
-        printf("Instruction is not suported\n");
-        exit(EXIT_FAILURE);
-#endif
 }
 
 /**
@@ -410,6 +493,7 @@ cl_write_dqa_flush(void *p, const uint64_t v)
         cl_write_dqa(p, v);
         cl_flush(p);
 }
+#endif
 
 /**
  * @brief Perform write operation to specified cache line
@@ -528,6 +612,7 @@ cl_write_nti(void *p, const uint64_t v)
 #endif
 }
 
+#ifdef __x86_64__
 /**
  * @brief non-temporal store vector version
  *
@@ -537,20 +622,13 @@ cl_write_nti(void *p, const uint64_t v)
 ALWAYS_INLINE void
 cl_write_nt512(void *p, const uint64_t v)
 {
-#if defined(__x86_64__) && defined(bit_AVX512F)
-       asm volatile("vmovq   %0, %%xmm1\n\t"
+        asm volatile("vmovq   %0, %%xmm1\n\t"
                      "vmovntpd %%zmm1, (%1)\n\t"
                      :
                      : "r"(v), "r"(p)
                      : "%zmm1", "memory");
-#else
-       UNUSED_PARAM(p);
-       UNUSED_PARAM(v);
-
-       printf("Instruction is not suported\n");
-       exit(EXIT_FAILURE);
-#endif
 }
+#endif
 
 /**
  * @brief Perform write operation to memory giving non-temporal hint with cache
@@ -566,6 +644,7 @@ cl_write_nti_clwb(void *p, const uint64_t v)
         cl_wb(p);
 }
 
+#ifdef __x86_64__
 /**
  * @brief Non temporal store vector version
  *
@@ -575,7 +654,6 @@ cl_write_nti_clwb(void *p, const uint64_t v)
 ALWAYS_INLINE void
 cl_write_ntdq(void *p, const uint64_t v)
 {
-#ifdef __x86_64__
         asm volatile("movq   %0, %%xmm1\n\t"
                      "movntdq %%xmm1, (%1)\n\t"
                      "movntdq %%xmm1, 16(%1)\n\t"
@@ -584,14 +662,8 @@ cl_write_ntdq(void *p, const uint64_t v)
                      :
                      : "r"(v), "r"(p)
                      : "%xmm1", "memory");
-#else
-        UNUSED_PARAM(p);
-        UNUSED_PARAM(v);
-
-        printf("Instruction is not suported\n");
-        exit(EXIT_FAILURE);
-#endif
 }
+#endif
 
 /**
  * @brief Function to perform non-temporal read operation
@@ -682,7 +754,7 @@ cl_read_dqa(void *p)
 ALWAYS_INLINE void
 mem_execute(const unsigned bw, const enum cl_type type)
 {
-        const uint64_t val = (uint64_t) rand();
+        const uint64_t val = (uint64_t)rand();
         char *cp = (char *)memchunk;
         unsigned i = 0;
         const size_t s = MEMCHUNK_SIZE / CL_SIZE; /* mem size in cache lines */
@@ -720,18 +792,22 @@ mem_execute(const unsigned bw, const enum cl_type type)
                 case CL_TYPE_READ_MOD_WRITE:
                         cl_read_mod_write(ptr, val);
                         break;
+#ifdef __x86_64__
                 case CL_TYPE_WRITE_DQA:
                         cl_write_dqa(ptr, val);
                         break;
                 case CL_TYPE_WRITE_DQA_FLUSH:
                         cl_write_dqa_flush(ptr, val);
                         break;
+#endif
                 case CL_TYPE_WRITE_WB:
                         cl_write(ptr, val);
                         break;
+#ifdef __x86_64__
                 case CL_TYPE_WRITE_WB_AVX512:
                         cl_write_avx512(ptr, val);
                         break;
+#endif
                 case CL_TYPE_WRITE_WB_CLWB:
                         cl_write_clwb(ptr, val);
                         break;
@@ -741,15 +817,17 @@ mem_execute(const unsigned bw, const enum cl_type type)
                 case CL_TYPE_WRITE_NTI:
                         cl_write_nti(ptr, val);
                         break;
-                case CL_TYPE_WRITE_NT512:
-                        cl_write_nt512(ptr, val);
-                        break;
                 case CL_TYPE_WRITE_NTI_CLWB:
                         cl_write_nti_clwb(ptr, val);
                         break;
+#ifdef __x86_64__
+                case CL_TYPE_WRITE_NT512:
+                        cl_write_nt512(ptr, val);
+                        break;
                 case CL_TYPE_WRITE_NTDQ:
                         cl_write_ntdq(ptr, val);
                         break;
+#endif
                 default:
                         assert(0);
                         break;
@@ -769,7 +847,8 @@ mem_execute(const unsigned bw, const enum cl_type type)
  *
  * @param argv list of arguments supplied by user
  */
-static void usage(char **argv)
+static void
+usage(char **argv)
 {
         printf("Usage: %s -c <cpu> -b <BW [MB/s]> <operation type>\n"
                "Description:\n"
@@ -786,17 +865,24 @@ static void usage(char **argv)
                "  --nt-read-sse      SSE NT loads\n"
                "  --read-mod-write   x86 load XOR write\n"
                "  --write            x86 stores\n"
+#ifdef __x86_64__
                "  --write-avx512     AVX512 stores\n"
+#endif
                "  --write-clwb       x86 stores + clwb\n"
-               "  --write-flush      x86 stores & clflush (naturally generates"
-                                    " loads & stores)\n"
+               "  --write-flush      x86 stores & clflush (naturally generates "
+               "loads & stores)\n"
+#ifdef __x86_64__
                "  --write-sse        SSE stores\n"
                "  --write-sse-flush  SSE stores & clflush (naturally generates "
-                                    "loads & stores)\n"
+               "loads & stores)\n"
+#endif
                "  --nt-write         x86 NT stores\n"
                "  --nt-write-avx512  AVX512 NT stores\n"
                "  --nt-write-clwb    x86 NT stores + clwb\n"
-               "  --nt-write-sse     SSE NT stores\n",
+#ifdef __x86_64__
+               "  --nt-write-sse     SSE NT stores\n"
+#endif
+               ,
                argv[0]);
 }
 
@@ -808,13 +894,13 @@ static void usage(char **argv)
  *
  * @retval long time taken to execute operation
  */
-ALWAYS_INLINE
-long get_usec_diff(struct timeval *tv_s, struct timeval *tv_e)
+ALWAYS_INLINE long
+get_usec_diff(struct timeval *tv_s, struct timeval *tv_e)
 {
         long usec_start, usec_end = 0;
 
-        usec_start = ((long)tv_s->tv_usec) + ((long)tv_s->tv_sec*1000000L);
-        usec_end = ((long)tv_e->tv_usec) + ((long)tv_e->tv_sec*1000000L);
+        usec_start = ((long)tv_s->tv_usec) + ((long)tv_s->tv_sec * 1000000L);
+        usec_end = ((long)tv_e->tv_usec) + ((long)tv_e->tv_sec * 1000000L);
 
         return usec_end - usec_start;
 }
@@ -825,8 +911,8 @@ long get_usec_diff(struct timeval *tv_s, struct timeval *tv_e)
  * @param usec_diff time taken to execute operation
  * @param interval maximum time operation should take
  */
-ALWAYS_INLINE
-void nano_sleep(const long interval, long usec_diff)
+ALWAYS_INLINE void
+nano_sleep(const long interval, long usec_diff)
 {
         struct timespec req, rem;
 
@@ -880,7 +966,8 @@ str_to_uint(const char *str, const unsigned base, unsigned *value)
         return 0;
 }
 
-int main(int argc, char **argv)
+int
+main(int argc, char **argv)
 {
         int cmd = EXIT_SUCCESS;
         enum cl_type type = CL_TYPE_INVALID;
@@ -888,7 +975,9 @@ int main(int argc, char **argv)
         unsigned cpu = UINT_MAX;
         int option_index;
         int ret;
+        uint64_t features;
 
+        /* clang-format off */
         struct option options[] = {
             {"bandwidth",       required_argument, 0, 'b'},
             {"cpu",             required_argument, 0, 'c'},
@@ -902,17 +991,26 @@ int main(int argc, char **argv)
             {"nt-read-sse",     no_argument, 0, CL_TYPE_READ_NTQ},
             {"read-mod-write",  no_argument, 0, CL_TYPE_READ_MOD_WRITE},
             {"write",           no_argument, 0, CL_TYPE_WRITE_WB},
+#ifdef __x86_64__
             {"write-avx512",    no_argument, 0, CL_TYPE_WRITE_WB_AVX512},
+#endif
             {"write-clwb",      no_argument, 0, CL_TYPE_WRITE_WB_CLWB},
             {"write-flush",     no_argument, 0, CL_TYPE_WRITE_WB_FLUSH},
+#ifdef __x86_64__
             {"write-sse",       no_argument, 0, CL_TYPE_WRITE_DQA},
             {"write-sse-flush", no_argument, 0, CL_TYPE_WRITE_DQA_FLUSH},
+#endif
             {"nt-write",        no_argument, 0, CL_TYPE_WRITE_NTI},
+#ifdef __x86_64__
             {"nt-write-avx512", no_argument, 0, CL_TYPE_WRITE_NT512},
+#endif
             {"nt-write-clwb",   no_argument, 0, CL_TYPE_WRITE_NTI_CLWB},
+#ifdef __x86_64__
             {"nt-write-sse",    no_argument, 0, CL_TYPE_WRITE_NTDQ},
+#endif
             {0, 0, 0, 0}
         };
+        /* clang-format on */
 
         /* Process command line arguments */
         while ((cmd = getopt_long_only(argc, argv, "b:c:", options,
@@ -942,17 +1040,23 @@ int main(int argc, char **argv)
                 case CL_TYPE_READ_WB:
                 case CL_TYPE_READ_WB_DQA:
                 case CL_TYPE_READ_MOD_WRITE:
+#ifdef __x86_64__
                 case CL_TYPE_WRITE_DQA:
                 case CL_TYPE_WRITE_DQA_FLUSH:
+#endif
                 case CL_TYPE_WRITE_WB:
+#ifdef __x86_64__
                 case CL_TYPE_WRITE_WB_AVX512:
+#endif
                 case CL_TYPE_WRITE_WB_CLWB:
                 case CL_TYPE_WRITE_WB_FLUSH:
                 case CL_TYPE_WRITE_NTI:
-                case CL_TYPE_WRITE_NT512:
                 case CL_TYPE_WRITE_NTI_CLWB:
+#ifdef __x86_64__
+                case CL_TYPE_WRITE_NT512:
                 case CL_TYPE_WRITE_NTDQ:
-                        type = (enum cl_type) cmd;
+#endif
+                        type = (enum cl_type)cmd;
                         break;
                 default:
                         usage(argv);
@@ -962,12 +1066,46 @@ int main(int argc, char **argv)
         }
 
         /* Check if user has supplied all required arguments */
-        if (type == CL_TYPE_INVALID || cpu == UINT_MAX || !mem_bw
-                        || optind < argc) {
+        if (type == CL_TYPE_INVALID || cpu == UINT_MAX || !mem_bw ||
+            optind < argc) {
                 usage(argv);
                 return EXIT_FAILURE;
         }
 
+        features = cpu_feature_detect();
+
+        switch (type) {
+        case CL_TYPE_READ_WB_DQA:
+#ifdef __x86_64__
+        case CL_TYPE_WRITE_DQA:
+        case CL_TYPE_WRITE_DQA_FLUSH:
+        case CL_TYPE_WRITE_NTDQ:
+#endif
+                if (!(features & CPU_FEATURE_SSE4_2)) {
+                        printf("No CPU support for SSE4.2 instructions!\n");
+                        return EXIT_FAILURE;
+                }
+                break;
+        case CL_TYPE_WRITE_NTI_CLWB:
+        case CL_TYPE_WRITE_WB_CLWB:
+                if (!(features & CPU_FEATURE_CLWB)) {
+                        printf("No CPU support for CLWB instruction!\n");
+                        return EXIT_FAILURE;
+                }
+                break;
+#ifdef __x86_64__
+        case CL_TYPE_WRITE_NT512:
+        case CL_TYPE_WRITE_WB_AVX512:
+                if (!(features & CPU_FEATURE_AVX512F)) {
+                        printf("No CPU support for AVX512 instructions!\n");
+                        return EXIT_FAILURE;
+                }
+                break;
+#endif
+        default:
+                break;
+        }
+
         printf("- THREAD logical core id: %u, "
                " memory bandwidth [MB]: %u, starting...\n",
                cpu, mem_bw);
